@@ -1530,7 +1530,7 @@ int execute(
           if (len < 256)
             {
             sprintf(errnomsg, "qmgr obj=%s svr=%s: %s\n",
-                    pname -> obj_name, Svrname(sp),  errmsg);
+              pname -> obj_name, Svrname(sp),  errmsg);
 
             if (! zopt) fprintf(stderr, "%s", errnomsg);
             }
@@ -2094,25 +2094,25 @@ int is_attr(
     *name_ptr = '\0';
     }
 
-  if (attr_public != NULL && (attr_type & TYPE_ATTR_PUBLIC))
+  if ((attr_public != NULL) &&
+      (attr_type & TYPE_ATTR_PUBLIC))
     {
     while (*attr_public != NULL && ret == FALSE)
       {
-/*      if (strncmp(name, *attr_public, strlen(*attr_public)) == 0)*/
-      if(strcmp(dupname, *attr_public) == 0)
+      if (strcmp(dupname, *attr_public) == 0)
         {
-          ret =  TRUE;
+        ret =  TRUE;
         }
 
       attr_public++;
       }
     }
 
-  if (attr_readonly != NULL && (attr_type & TYPE_ATTR_READONLY))
+  if ((attr_readonly != NULL) &&
+      (attr_type & TYPE_ATTR_READONLY))
     {
     while (*attr_readonly != NULL && ret == FALSE)
       {
-      /*if (strncmp(name, *attr_readonly, strlen(*attr_readonly)) == 0)*/
       if (strcmp(dupname, *attr_readonly) == 0)
         ret = TRUE;
 
@@ -2120,6 +2120,8 @@ int is_attr(
       }
     }
 
+  free(dupname);
+
   return(ret);
   }  /* END is_attr() */
 
@@ -2230,17 +2232,17 @@ void show_help(
 
 int parse(
 
-  char    *request,
-  int     *oper,
-  int     *type,
-  char   **names,
+  char            *request,
+  int             *oper,
+  int             *type,
+  char           **names,
   struct attropl **attr)
 
   {
-  int error;
-  int lp;                     /* Length of current string */
-  int len;        /* ammount parsed by parse_request */
-  int i;        /* loop var */
+  int         error;
+  int         lp;       /* Length of current string */
+  int         len;      /* ammount parsed by parse_request */
+  int         i;        /* loop var */
   static char req[MAX_REQ_WORDS][MAX_REQ_WORD_LEN] = { {'\0'} };
 
   /* clear old data in req */
@@ -2252,7 +2254,7 @@ int parse(
 
   len = parse_request(request, req);
 
-  if (len != 0)  /* error in parse_request */
+  if (len != 0)
     {
     lp = strlen(req[IND_CMD]);
 
@@ -2875,15 +2877,16 @@ int parse_request(
   char  req[][MAX_REQ_WORD_LEN])
 
   {
-  char *foreptr, *backptr;
-  int len;
-  int i = 0;
-  int chars_parsed = 0;
-  int error = 0;
+  char *foreptr;
+  char *backptr;
+  int   len = 0;
+  int   i = 0;
+  int   chars_parsed = 0;
+  int   error = 0;
 
   foreptr = request;
 
-  for (i = 0;!EOL(*foreptr) && (i < MAX_REQ_WORDS) && (error == 0);)
+  for (i = 0; !EOL(*foreptr) && (i < MAX_REQ_WORDS) && (error == 0);)
     {
     while (White(*foreptr))
       foreptr++;
@@ -2895,35 +2898,30 @@ int parse_request(
 
     len = foreptr - backptr;
 
-    if (len > MAX_REQ_WORD_LEN)
+    if (len >= MAX_REQ_WORD_LEN)
       {
       error = 1;
       chars_parsed = (int)(foreptr - request);
 
-      if (! zopt) fprintf(stderr, "qmgr: max word length exceeded\n");
+      if (!zopt)
+        fprintf(stderr, "qmgr: max word length exceeded\n");
 
       CaretErr(request, chars_parsed);
+
+      return(error);
       }
 
     strncpy(req[i], backptr, len);
-
     req[i][len] = '\0';
+
     i++;
     }  /* END for (i) */
 
   chars_parsed = foreptr - request;
 
-  if (error == 0)
-    {
-    /* FAILURE */
-
-    return(chars_parsed);
-    }
-
   /* SUCCESS */
-
-  return(0);
-  }
+  return(chars_parsed);
+  } /* END parse_request() */
 
 
 /* END qmgr.c */
