@@ -94,7 +94,7 @@ int get_alps_statuses(struct pbsnode *parent, struct batch_request *preq, int *b
 
 int destroy_alps_reservation(char *reservation_id, char *apbasil_path, char *apbasil_protocol);
 
-int create_alps_reservation(char *exec_hosts, char *username, char *jobid, char *apbasil_path, char *apbasil_protocol, long long pagg_id, char **reservation_id);
+int create_alps_reservation(char *exec_hosts, char *username, char *jobid, char *apbasil_path, char *apbasil_protocol, long long pagg_id, int use_nppn, char **reservation_id);
 
 int find_error_type(xmlNode *node);
 
