@@ -85,11 +85,11 @@
 
 #ifndef _PBS_IFL_DEF
 #define _PBS_IFL_DEF
+#include <sys/socket.h>
+
 #include "u_hash_map_structs.h"
 #include "u_memmgr.h"
 
-#include <sys/socket.h>
-
 /* Attribute Names used by user commands */
 
 #define ATTR_a "Execution_Time"
@@ -116,6 +116,7 @@
 #define ATTR_login_node_id "login_node_id"
 #define ATTR_login_prop "login_property"
 #define ATTR_external_nodes "external_nodes"
+#define ATTR_multi_req_alps "multi_req_alps"
 #define ATTR_M "Mail_Users"
 #define ATTR_N "Job_Name"
 #define ATTR_S "Shell_Path_List"
@@ -465,7 +466,11 @@
 #define PBS_MAXQUEUENAME 15 /* max queue name length */
 #define PBS_MAXSERVERNAME PBS_MAXHOSTNAME /* max server name length */
 #define PBS_MAXJOBARRAYLEN      7       /* number of characters allowed in jobarray portion of job id, including '[]' */
+#ifdef USE_MAXINT_JOBIDS
+#define PBS_MAXSEQNUM  12 /* max sequence number length */
+#else
 #define PBS_MAXSEQNUM  8 /* max sequence number length */
+#endif
 #define PBS_MAXPORTNUM  5 /* udp/tcp port numbers max=16 bits */
 #define PBS_MAXJOBARRAY  99999
 #define PBS_MAXSVRJOBID  (PBS_MAXSEQNUM + PBS_MAXSERVERNAME + PBS_MAXPORTNUM + PBS_MAXJOBARRAYLEN + 2 ) /* server job id size */
