@@ -157,17 +157,24 @@ struct prop
 
 struct jobinfo
   {
-  char            jobid[PBS_MAXSVRJOBID];
+  char            jobid[PBS_MAXSVRJOBID+1];
 
   struct jobinfo *next;
   };
 
+typedef struct alps_req_data
+  {
+  dynamic_string *node_list;
+  int             ppn;
+  } alps_req_data;
+
 typedef struct single_spec_data
   {
-  int          nodes; /* nodes needed for this req */
-  int          ppn;   /* ppn for this req */
-  int          gpu;   /* gpus for this req */
-  struct prop *prop;  /* node properties needed */
+  int          nodes;   /* nodes needed for this req */
+  int          ppn;     /* ppn for this req */
+  int          gpu;     /* gpus for this req */
+  int          req_id;  /* the id of this alps req - used only for cray */
+  struct prop *prop;    /* node properties needed */
   } single_spec_data;
 
 typedef struct complete_spec_data
@@ -207,7 +214,7 @@ struct pbssubn
 
 struct gpusubn
   {
-  char            jobid[PBS_MAXSVRJOBID];   /* jobid on this gpu subnode */
+  char            jobid[PBS_MAXSVRJOBID+1];   /* jobid on this gpu subnode */
   unsigned short  inuse;  /* 1 if this node is in use, 0 otherwise */
   enum gpstatit   state;  /* gpu state determined by server */
   enum gpmodeit   mode;   /* gpu mode from hardware */
@@ -325,6 +332,8 @@ struct pbsnode
   struct AvlNode       *node_boards;         /* private tree of numa nodes */
   char                 *numa_str;            /* comma-delimited string of processor values */
   char                 *gpu_str;             /* comma-delimited string of the number of gpus for each nodeboard */
+
+  unsigned char         nd_mom_reported_down;/* notes that the mom reported its own shutdown */
   
   unsigned char         nd_is_alps_reporter;
   unsigned char         nd_is_alps_login;
@@ -334,8 +343,6 @@ struct pbsnode
   pthread_mutex_t      *nd_mutex;            /* semaphore for accessing this node's data */
   };
 
-extern struct pbsnode *alps_reporter;
-
 
 #define INITIAL_NODE_SIZE  20
 
