@@ -210,6 +210,9 @@ typedef struct pbs_queue
   } pbs_queue;
 
 
+int que_save(struct pbs_queue *pque);
+
+
 typedef struct all_queues
   {
   resizable_array *ra;
@@ -241,11 +244,15 @@ int   site_alt_router(job *, pbs_queue *, long);
 int   site_acl_check(job *, pbs_queue *);
 void  set_chkpt_deflt(job *, pbs_queue *);
 
+extern all_queues svr_queues;
+
 struct job;
 
 pbs_queue *lock_queue_with_job_held(pbs_queue *pque, struct job **pjob_ptr);
 int lock_queue(struct pbs_queue *the_queue, const char *method_name, char *msg, int logging);
 int unlock_queue(struct pbs_queue *the_queue, const char *method_name, char *msg, int logging);
+int lock_allques_mutex(all_queues *all_ques, const char *method_name, char *msg, int logging);
+int unlock_allques_mutex(all_queues *all_ques, const char *method_name, char *msg, int logging);
 pbs_queue *next_queue(all_queues *,int *);
 int        insert_queue(all_queues *,pbs_queue *);
 int        remove_queue(all_queues *,pbs_queue *);
