@@ -57,11 +57,10 @@ extern int   svr_connect(pbs_net_t, unsigned int, int *, struct pbsnode *, void
 
 #ifdef WORK_TASK_H
 extern void  release_req(struct work_task *);
-#ifdef BATCH_REQUEST_H
-extern int   issue_Drequest(int, struct batch_request *, void (*)(), struct work_task **);
-#endif /* BATCH_REQUEST_H */
 #endif /* WORK_TASK_H */
 
+extern int   issue_Drequest(int, struct batch_request *);
+
 
 /* The following is used in req_stat.c and req_select.c */
 
