@@ -96,12 +96,9 @@
 #include "portability.h"
 #include "server_limits.h"
 #include "list_link.h"
-#include "attribute.h"
 #include "pbs_nodes.h"
 #include "libpbs.h"
 #include "pbs_ifl.h"
-#include "resource.h"
-#include "svrfunc.h"
 #include "pbs_error.h"
 #include "log.h"
 #include "mcom.h"
