@@ -177,6 +177,7 @@ int decode_arst_direct(
   if ((pbuf = calloc(1, (unsigned)ssize)) == NULL)
     {
     /* FAILURE */
+    free(tmpval);
 
     return(PBSE_SYSTEM);
     }
@@ -188,6 +189,8 @@ int decode_arst_direct(
   if ((stp = (struct array_strings *)calloc(1, bksize)) == NULL)
     {
     /* FAILURE */
+    free(tmpval);
+    free(pbuf);
 
     return(PBSE_SYSTEM);
     }
@@ -421,13 +424,13 @@ int encode_arst(
   int             perm)   /* only used for resources */
 
   {
-  char  *end;
-  int   i;
-  int   j;
+  char     *end;
+  int       i;
+  int       j;
   svrattrl *pal;
-  char  *pc;
-  char   *pfrom;
-  char   separator;
+  char     *pc;
+  char     *pfrom;
+  char      separator;
 
   if (attr == NULL)
     {
@@ -779,7 +782,10 @@ int set_arst(
       pc = calloc(1, need);
 
       if (pc == NULL)
+        {
+        free(tmp_arst);
         return(PBSE_SYSTEM);
+        }
 
       memset(pc, 0, need);
 
