@@ -137,7 +137,7 @@
 
 dis_long_double_t disrl(
 
-  int  stream,
+  struct tcp_chan *chan,
   int *retval)
 
   {
@@ -148,18 +148,15 @@ dis_long_double_t disrl(
   unsigned ndigs;
   unsigned nskips;
   dis_long_double_t  ldval;
-  int (*disr_commit)(int stream, int commit);
 
   assert(retval != NULL);
 
-  disr_commit = tcp_rcommit;
-
   ldval = 0.0L;
-  locret = disrl_(stream, &ldval, &ndigs, &nskips, LDBL_DIG, 1);
+  locret = disrl_(chan, &ldval, &ndigs, &nskips, LDBL_DIG, 1);
 
   if (locret == DIS_SUCCESS)
     {
-    locret = disrsi_(stream, &negate, &uexpon, 1);
+    locret = disrsi_(chan, &negate, &uexpon, 1);
 
     if (locret == DIS_SUCCESS)
       {
@@ -200,7 +197,7 @@ dis_long_double_t disrl(
       }
     }
 
-  if ((*disr_commit)(stream, locret == DIS_SUCCESS) < 0)
+  if (tcp_rcommit(chan, locret == DIS_SUCCESS) < 0)
     locret = DIS_NOCOMMIT;
 
   *retval = locret;
