@@ -104,21 +104,21 @@
 int diswf(
     
   struct tcp_chan *chan,
-  double value)
+  double           value)
   
   {
-  int  c;
-  int  expon;
-  unsigned ndigs;
-  int  negate;
-  int  retval;
-  unsigned pow2;
-  char  *cp;
-  char  *ocp;
-  double  dval;
-  char  scratch[DIS_BUFSIZ+1];
+  int       c;
+  int       expon;
+  unsigned  ndigs;
+  int       negate;
+  int       retval;
+  unsigned  pow2;
+  char     *cp;
+  char     *ocp;
+  double    dval;
+  char      scratch[DIS_BUFSIZ];
 
-  memset(scratch, 0, DIS_BUFSIZ+1);
+  memset(scratch, 0, sizeof(scratch));
   /* Make zero a special case.  If we don't it will blow exponent  */
   /* calculation.        */
 
@@ -187,7 +187,7 @@ int diswf(
 
   /* Starting in the middle of the buffer, convert coefficient digits, */
   /* most significant first.      */
-  ocp = cp = &scratch[DIS_BUFSIZ - FLT_DIG];
+  ocp = cp = &scratch[sizeof(scratch) - 1 - FLT_DIG];
 
   ndigs = FLT_DIG;
 
