@@ -87,6 +87,7 @@
 #include <stdio.h>
 #include "libpbs.h"
 #include "dis.h"
+#include "server_limits.h"
 
 int PBSD_mgr_put(
 
@@ -103,6 +104,10 @@ int PBSD_mgr_put(
   int sock;
   struct tcp_chan *chan = NULL;
 
+  if (c < 0 || c >= PBS_NET_MAX_CONNECTIONS) {
+      return(PBSE_BAD_PARAMETER);
+  }
+
   pthread_mutex_lock(connection[c].ch_mutex);
 
   sock = connection[c].ch_socket;
@@ -111,11 +116,11 @@ int PBSD_mgr_put(
     {
     pthread_mutex_unlock(connection[c].ch_mutex);
     rc = PBSE_PROTOCOL;
-    return rc;
+    return(rc);
     }
   else if ((rc = encode_DIS_ReqHdr(chan, function, pbs_current_user)) ||
-      (rc = encode_DIS_Manage(chan, command, objtype, objname, aoplp)) ||
-      (rc = encode_DIS_ReqExtend(chan, extend)))
+           (rc = encode_DIS_Manage(chan, command, objtype, objname, aoplp)) ||
+           (rc = encode_DIS_ReqExtend(chan, extend)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
 
