@@ -90,16 +90,17 @@
 
 int PBSD_manager(
 
-  int c,
-  int function,
-  int command,
-  int objtype,
-  char *objname,
+  int             c,
+  int             function,
+  int             command,
+  int             objtype,
+  char           *objname,
   struct attropl *aoplp,
-  char *extend)
+  char           *extend,
+  int            *local_errno)
 
   {
-  int rc;
+  int                 rc;
 
   struct batch_reply *reply;
 
@@ -119,13 +120,18 @@ int PBSD_manager(
     return(rc);
     }
 
-  /* read reply from stream into presentation element */
+  pthread_mutex_lock(connection[c].ch_mutex);
 
-  reply = PBSD_rdrpy(c);
+  /* read reply from stream into presentation element */
+  reply = PBSD_rdrpy(local_errno, c);
 
   PBSD_FreeReply(reply);
 
-  return(connection[c].ch_errno);
+  rc = connection[c].ch_errno;
+
+  pthread_mutex_unlock(connection[c].ch_mutex);
+
+  return(rc);
   }  /* END PBSD_manager() */
 
 /* END PBSD_manager.c */
