@@ -101,29 +101,34 @@ int PBSD_sig_put(
   {
   int sock;
   int rc = 0;
+  struct tcp_chan *chan = NULL;
 
   pthread_mutex_lock(connection[c].ch_mutex);
 
   sock = connection[c].ch_socket;
-  DIS_tcp_setup(sock);
-
-  if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_SignalJob, pbs_current_user)) ||
-      (rc = encode_DIS_SignalJob(sock, jobid, signal)) ||
-      (rc = encode_DIS_ReqExtend(sock, extend)))
+  if ((chan = DIS_tcp_setup(sock)) == NULL)
+    {
+    rc = PBSE_PROTOCOL;
+    return rc;
+    }
+  else if ((rc = encode_DIS_ReqHdr(chan, PBS_BATCH_SignalJob, pbs_current_user))
+      || (rc = encode_DIS_SignalJob(chan, jobid, signal))
+      || (rc = encode_DIS_ReqExtend(chan, extend)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
 
     pthread_mutex_unlock(connection[c].ch_mutex);
-
+    DIS_tcp_cleanup(chan);
     return (PBSE_PROTOCOL);
     }
 
-  if (DIS_tcp_wflush(sock))
+  if (DIS_tcp_wflush(chan))
     {
     rc = PBSE_PROTOCOL;
     }
 
   pthread_mutex_unlock(connection[c].ch_mutex);
+  DIS_tcp_cleanup(chan);
 
   return rc;
   } /* END PBSD_sig_put() */
@@ -139,30 +144,35 @@ int PBSD_async_sig_put(
   {
   int sock;
   int rc = 0;
+  struct tcp_chan *chan = NULL;
 
   pthread_mutex_lock(connection[c].ch_mutex);
 
   sock = connection[c].ch_socket;
-  DIS_tcp_setup(sock);
-
-  if ((rc = encode_DIS_ReqHdr(sock,PBS_BATCH_SignalJob,pbs_current_user)) ||
-      (rc = encode_DIS_SignalJob(sock,jobid,signal)) ||
-      (rc = encode_DIS_ReqExtend(sock,extend)))
+  if ((chan = DIS_tcp_setup(sock)) == NULL)
+    {
+    rc = PBSE_PROTOCOL;
+    return rc;
+    }
+  else if ((rc = encode_DIS_ReqHdr(chan,PBS_BATCH_SignalJob,pbs_current_user))
+      || (rc = encode_DIS_SignalJob(chan,jobid,signal))
+      || (rc = encode_DIS_ReqExtend(chan,extend)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
 
     pthread_mutex_unlock(connection[c].ch_mutex);
-
+    DIS_tcp_cleanup(chan);
     return (PBSE_PROTOCOL);
     }
 
   pthread_mutex_unlock(connection[c].ch_mutex);
     
-  if (DIS_tcp_wflush(sock))
+  if (DIS_tcp_wflush(chan))
     {
     rc = PBSE_PROTOCOL;
     }
 
+  DIS_tcp_cleanup(chan);
   return(rc);
   } /* END PBSD_async_sig_put() */
 
