@@ -102,6 +102,7 @@ char *pbs_locjob_err(
   struct batch_reply *reply;
   char       *ploc = (char *)0;
   int sock;
+  struct tcp_chan *chan = NULL;
 
 
   if ((jobid == (char *)0) || (*jobid == '\0'))
@@ -116,27 +117,32 @@ char *pbs_locjob_err(
 
   /* setup DIS support routines for following DIS calls */
 
-  DIS_tcp_setup(sock);
-
-  if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_LocateJob, pbs_current_user)) ||
-      (rc = encode_DIS_JobId(sock, jobid))    ||
-      (rc = encode_DIS_ReqExtend(sock, extend)))
+  if ((chan = DIS_tcp_setup(sock)) == NULL)
+    {
+    pthread_mutex_unlock(connection[c].ch_mutex);
+    return NULL;
+    }
+  else if ((rc = encode_DIS_ReqHdr(chan, PBS_BATCH_LocateJob, pbs_current_user))
+      || (rc = encode_DIS_JobId(chan, jobid))
+      || (rc = encode_DIS_ReqExtend(chan, extend)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
 
     pthread_mutex_unlock(connection[c].ch_mutex);
 
     *local_errno = PBSE_PROTOCOL;
+    DIS_tcp_cleanup(chan);
     return(NULL);
     }
 
   /* write data over tcp stream */
 
-  if (DIS_tcp_wflush(sock))
+  if (DIS_tcp_wflush(chan))
     {
     pthread_mutex_unlock(connection[c].ch_mutex);
 
     *local_errno = PBSE_PROTOCOL;
+    DIS_tcp_cleanup(chan);
     return(NULL);
     }
 
@@ -165,7 +171,7 @@ char *pbs_locjob_err(
   PBSD_FreeReply(reply);
 
   pthread_mutex_unlock(connection[c].ch_mutex);
-
+  DIS_tcp_cleanup(chan);
   return(ploc);
   } /* END pbs_locjob_err() */
 
