@@ -114,16 +114,14 @@
 ** Set up a debug print macro.
 */
 #ifdef  DEBUG
-#define DBPRT(x) \
-    { \
-    int err = errno; \
-    printf x; \
-    errno = err; \
-    }
-#define DOID(x)  static char id[] = x;
+  #define TM_DBPRT(x) \
+      { \
+      int err = errno; \
+      printf x; \
+      errno = err; \
+      }
 #else
-#define DBPRT(x)
-#define DOID(x)
+  #define TM_DBPRT(x)
 #endif
 
 #ifndef MIN
@@ -172,8 +170,10 @@ static event_info *event_hash[EVENT_HASH];
 /*
 ** Find an event number or return a NULL.
 */
-static event_info *
-find_event(tm_event_t x)
+event_info *find_event(
+    
+  tm_event_t x)
+
   {
   event_info *ep;
 
@@ -189,10 +189,11 @@ find_event(tm_event_t x)
 /*
 ** Delete an event.
 */
-static void
-del_event(event_info *ep)
-  {
+void del_event(
+    
+  event_info *ep)
 
+  {
   /* unlink event from hash list */
   if (ep->e_prev)
     ep->e_prev->e_next = ep->e_next;
@@ -229,7 +230,7 @@ del_event(event_info *ep)
       break;
 
     default:
-      DBPRT(("del_event: unknown event command %d\n", ep->e_mtype))
+      TM_DBPRT(("del_event: unknown event command %d\n", ep->e_mtype))
       break;
     }
 
@@ -247,8 +248,8 @@ del_event(event_info *ep)
 /*
 ** Create a new event number.
 */
-static tm_event_t
-new_event(void)
+tm_event_t new_event(void)
+
   {
   static tm_event_t next_event = TM_NULL_EVENT + 1;
   event_info  *ep;
@@ -277,8 +278,12 @@ new_event(void)
 /*
 ** Link new event number into the above hash table.
 */
-static void
-add_event(tm_event_t event, tm_node_id node, int type, void *info)
+void add_event(
+    
+  tm_event_t  event,
+  tm_node_id  node,
+  int         type,
+  void       *info)
   {
   event_info  *ep, **head;
 
@@ -324,8 +329,10 @@ static task_info *task_hash[TASK_HASH];
 /*
 ** Find a task table entry for a given task number or return a NULL.
 */
-static task_info *
-find_task(tm_task_id x)
+task_info *find_task(
+    
+  tm_task_id x)
+
   {
   task_info *tp;
 
@@ -342,32 +349,35 @@ find_task(tm_task_id x)
 ** Create a new task entry and link it into the above hash
 ** table.
 */
-static tm_task_id
-new_task(char *jobid, tm_node_id node, tm_task_id task)
+tm_task_id new_task(
+    
+  char       *jobid,
+  tm_node_id  node,
+  tm_task_id  task)
+
   {
-  DOID("new_task")
   task_info  *tp, **head;
 
-  DBPRT(("%s: jobid=%s node=%d task=%lu\n",
-         id, jobid, node, (unsigned long)task))
+  TM_DBPRT(("%s: jobid=%s node=%d task=%lu\n",
+         __func__, jobid, node, (unsigned long)task))
 
   if (jobid != tm_jobid && strcmp(jobid, tm_jobid) != 0)
     {
-    DBPRT(("%s: task job %s not my job %s\n",
-           id, jobid, tm_jobid))
+    TM_DBPRT(("%s: task job %s not my job %s\n",
+           __func__, jobid, tm_jobid))
     return TM_NULL_TASK;
     }
 
   if (node == TM_ERROR_NODE)
     {
-    DBPRT(("%s: called with TM_ERROR_NODE\n", id))
+    TM_DBPRT(("%s: called with TM_ERROR_NODE\n", __func__))
     return TM_NULL_TASK;
     }
 
   if ((tp = find_task(task)) != NULL)
     {
-    DBPRT(("%s: task %lu found with node %d should be %d\n",
-           id, (unsigned long)task, tp->t_node, node))
+    TM_DBPRT(("%s: task %lu found with node %d should be %d\n",
+           __func__, (unsigned long)task, tp->t_node, node))
     return task;
     }
 
@@ -458,7 +468,7 @@ static int localmom(void)
 
     if (getaddrinfo("localhost", NULL, NULL, &addr_info) != 0)
       {
-      DBPRT(("tm_init: localhost not found\n"))
+      TM_DBPRT(("tm_init: localhost not found\n"))
 
       return(-1);
       }
@@ -562,8 +572,8 @@ static int localmom(void)
 
 static int startcom(
 
-  int        com,
-  tm_event_t event,
+  int               com,
+  tm_event_t        event,
   struct tcp_chan **pchan)
 
   {
@@ -618,7 +628,7 @@ static int startcom(
 
 done:
 
-  DBPRT(("startcom: send error %s\n",
+  TM_DBPRT(("startcom: send error %s\n",
          dis_emsg[ret]))
   if (chan != NULL)
     DIS_tcp_close(chan);
@@ -946,6 +956,7 @@ int tm_obit(
   tm_task_id  tid,  /* in  */
   int        *obitval, /* out */
   tm_event_t *event)  /* out */
+
   {
   int rc = TM_SUCCESS;
   task_info *tp;
@@ -1005,14 +1016,14 @@ struct taskhold
 ** is a valid node number, it returns the event that the list of
 ** tasks on <node> is available.
 */
-int
-tm_taskinfo(
-  tm_node_id node,  /* in  */
+int tm_taskinfo(
+
+  tm_node_id  node,  /* in  */
   tm_task_id *tid_list, /* out */
-  int list_size, /* in  */
-  int *ntasks, /* out */
-  tm_event_t *event  /* out */
-)
+  int         list_size, /* in  */
+  int        *ntasks, /* out */
+  tm_event_t *event)  /* out */
+
   {
   struct taskhold *thold;
   struct tcp_chan *chan = NULL;
@@ -1056,11 +1067,11 @@ tm_taskinfo(
 ** Returns the job-relative node number that holds or held <tid>.  In
 ** case of an error, it returns TM_ERROR_NODE.
 */
-int
-tm_atnode(
-  tm_task_id tid,  /* in  */
-  tm_node_id *node  /* out */
-)
+int tm_atnode(
+
+  tm_task_id  tid,  /* in  */
+  tm_node_id *node)  /* out */
+
   {
   task_info *tp;
 
@@ -1088,12 +1099,13 @@ struct reschold
 ** <node> is available.  It returns ERROR_EVENT otherwise.
 */
 int tm_rescinfo(
-  tm_node_id node,  /* in  */
-  char *resource, /* out */
-  int len,  /* in  */
-  tm_event_t *event)  /* out */
-  {
 
+  tm_node_id  node,  /* in  */
+  char       *resource, /* out */
+  int         len,  /* in  */
+  tm_event_t *event)  /* out */
+
+  {
   struct reschold *rhold;
   struct tcp_chan *chan = NULL;
 
@@ -1128,7 +1140,10 @@ int tm_rescinfo(
   add_event(*event, node, TM_RESOURCES, (void *)rhold);
 
   return TM_SUCCESS;
-  }
+  } /* END tm_rescinfo() */
+
+
+
 
 /*
 ** Posts the first <nbytes> of a copy of *<info> within MOM on
@@ -1136,13 +1151,13 @@ int tm_rescinfo(
 ** non-NULL, it returns the event that the effort to post *<info>
 ** is complete.  It returns ERROR_EVENT otherwise.
 */
-int
-tm_publish(
-  char *name,  /* in  */
-  void *info,  /* in  */
-  int len,  /* in  */
-  tm_event_t *event  /* out */
-)
+int tm_publish(
+  
+  char       *name,  /* in  */
+  void       *info,  /* in  */
+  int         len,  /* in  */
+  tm_event_t *event)  /* out */
+
   {
   int rc = TM_SUCCESS;
   struct tcp_chan *chan = NULL;
@@ -1176,7 +1191,7 @@ tm_publish_cleanup:
     DIS_tcp_cleanup(chan);
 
   return rc;
-  }
+  } /* tm_publish() */
 
 struct infohold
   {
@@ -1190,18 +1205,18 @@ struct infohold
 ** <tid> is a valid task, it returns the event that the
 ** string specifying the info posted by <tid> is available.
 */
-int
-tm_subscribe(
-  tm_task_id tid,  /* in  */
-  char *name,  /* in  */
-  void *info,  /* out */
-  int len,  /* in  */
-  int *info_len, /* out */
-  tm_event_t *event  /* out */
-)
+int tm_subscribe(
+  
+  tm_task_id  tid,     /* in  */
+  char       *name,    /* in  */
+  void       *info,    /* out */
+  int         len,     /* in  */
+  int        *info_len,/* out */
+  tm_event_t *event)    /* out */
+  
   {
-  int rc = TM_SUCCESS;
-  task_info  *tp;
+  int              rc = TM_SUCCESS;
+  task_info       *tp;
   struct tcp_chan *chan = NULL;
 
   struct infohold *ihold;
@@ -1385,14 +1400,13 @@ tm_register(tm_whattodo_t *what, tm_event_t *event)
 */
 
 int tm_poll(
-    tm_event_t poll_event,
-    tm_event_t *result_event,
-    int  wait,
-    int  *tm_errno)
+
+  tm_event_t  poll_event,
+  tm_event_t *result_event,
+  int         wait,
+  int        *tm_errno)
 
   {
-  DOID("tm_poll")
-
   int  num, i;
   int  ret, mtype, nnodes;
   int  prot, protver;
@@ -1401,8 +1415,8 @@ int tm_poll(
   tm_task_id tid, *tidp;
   tm_event_t nevent;
   tm_node_id node;
-  char  *jobid;
-  char  *info;
+  char  *jobid = NULL;
+  char  *info = NULL;
 
   struct tm_roots *roots;
 
@@ -1431,16 +1445,16 @@ int tm_poll(
 
   if (event_count == 0)
     {
-    DBPRT(("%s: no events waiting\n",
-           id))
+    TM_DBPRT(("%s: no events waiting\n",
+           __func__))
 
     return(TM_ENOTFOUND);
     }
 
   if (local_conn < 0)
     {
-    DBPRT(("%s: INTERNAL ERROR %d events but no connection (%d)\n",
-           id, event_count, local_conn))
+    TM_DBPRT(("%s: INTERNAL ERROR %d events but no connection (%d)\n",
+           __func__, event_count, local_conn))
 
     if (static_chan != NULL)
       {
@@ -1452,7 +1466,7 @@ int tm_poll(
 
   if ((static_chan == NULL) && ((static_chan = DIS_tcp_setup(local_conn)) == NULL))
     {
-    DBPRT(("%s: Error allocating memory for sock buffer %d", __func__, PBSE_MEM_MALLOC))
+    TM_DBPRT(("%s: Error allocating memory for sock buffer %d", __func__, PBSE_MEM_MALLOC))
       return TM_BADINIT;
     }
 
@@ -1473,13 +1487,13 @@ int tm_poll(
     }
   else if (ret != DIS_SUCCESS)
     {
-    DBPRT(("%s: protocol number dis error %d\n", id, ret))
+    TM_DBPRT(("%s: protocol number dis error %d\n", __func__, ret))
     goto tm_poll_error;
     }
 
   if (prot != TM_PROTOCOL)
     {
-    DBPRT(("%s: bad protocol number %d\n", id, prot))
+    TM_DBPRT(("%s: bad protocol number %d\n", __func__, prot))
     goto tm_poll_error;
     }
 
@@ -1493,13 +1507,13 @@ int tm_poll(
 
   if (ret != DIS_SUCCESS)
     {
-    DBPRT(("%s: protocol version dis error %d\n", id, ret))
+    TM_DBPRT(("%s: protocol version dis error %d\n", __func__, ret))
     goto tm_poll_error;
     }
 
   if (protver != TM_PROTOCOL_VER)
     {
-    DBPRT(("%s: bad protocol version %d\n", id, protver))
+    TM_DBPRT(("%s: bad protocol version %d\n", __func__, protver))
     goto tm_poll_error;
     }
 
@@ -1507,7 +1521,7 @@ int tm_poll(
 
   if (ret != DIS_SUCCESS)
     {
-    DBPRT(("%s: mtype dis error %d\n", id, ret))
+    TM_DBPRT(("%s: mtype dis error %d\n", __func__, ret))
     goto tm_poll_error;
     }
 
@@ -1515,17 +1529,17 @@ int tm_poll(
 
   if (ret != DIS_SUCCESS)
     {
-    DBPRT(("%s: event dis error %d\n", id, ret))
+    TM_DBPRT(("%s: event dis error %d\n", __func__, ret))
     goto tm_poll_error;
     }
 
   *result_event = nevent;
 
-  DBPRT(("%s: got event %d return %d\n", id, nevent, mtype))
+  TM_DBPRT(("%s: got event %d return %d\n", __func__, nevent, mtype))
 
   if ((ep = find_event(nevent)) == NULL)
     {
-    DBPRT(("%s: No event found for number %d\n", id, nevent));
+    TM_DBPRT(("%s: No event found for number %d\n", __func__, nevent));
     DIS_tcp_close(static_chan);
     static_chan = NULL;
     local_conn = -1;
@@ -1535,7 +1549,7 @@ int tm_poll(
   if (mtype == TM_ERROR)   /* problem, read error num */
     {
     *tm_errno = disrsi(static_chan, &ret);
-    DBPRT(("%s: event %d error %d\n", id, nevent, *tm_errno));
+    TM_DBPRT(("%s: event %d error %d\n", __func__, nevent, *tm_errno));
     goto tm_poll_done;
     }
 
@@ -1561,7 +1575,7 @@ int tm_poll(
 
       if (ret != DIS_SUCCESS)
         {
-        DBPRT(("%s: INIT failed nnodes\n", id))
+        TM_DBPRT(("%s: INIT failed nnodes\n", __func__))
         goto tm_poll_error;
         }
 
@@ -1575,7 +1589,7 @@ int tm_poll(
         goto tm_poll_error;
         }
 
-      DBPRT(("%s: INIT nodes %d\n", id, nnodes))
+      TM_DBPRT(("%s: INIT nodes %d\n", __func__, nnodes))
 
       for (i = 0; i < nnodes; i++)
         {
@@ -1583,7 +1597,7 @@ int tm_poll(
 
         if (ret != DIS_SUCCESS)
           {
-          DBPRT(("%s: INIT failed nodeid %d\n", id, i))
+          TM_DBPRT(("%s: INIT failed nodeid %d\n", __func__, i))
           goto tm_poll_error;
           }
         }
@@ -1594,31 +1608,31 @@ int tm_poll(
 
       if (ret != DIS_SUCCESS)
         {
-        DBPRT(("%s: INIT failed jobid\n", id))
+        TM_DBPRT(("%s: INIT failed jobid\n", __func__))
         goto tm_poll_error;
         }
 
-      DBPRT(("%s: INIT daddy jobid %s\n", id, jobid))
+      TM_DBPRT(("%s: INIT daddy jobid %s\n", __func__, jobid))
 
       node = disrsi(static_chan, &ret);
 
       if (ret != DIS_SUCCESS)
         {
-        DBPRT(("%s: INIT failed parent nodeid\n", id))
+        TM_DBPRT(("%s: INIT failed parent nodeid\n", __func__))
         goto tm_poll_error;
         }
 
-      DBPRT(("%s: INIT daddy node %d\n", id, node))
+      TM_DBPRT(("%s: INIT daddy node %d\n", __func__, node))
 
       tid = disrsi(static_chan, &ret);
 
       if (ret != DIS_SUCCESS)
         {
-        DBPRT(("%s: INIT failed parent taskid\n", id))
+        TM_DBPRT(("%s: INIT failed parent taskid\n", __func__))
         goto tm_poll_error;
         }
 
-      DBPRT(("%s: INIT daddy tid %lu\n", id, (unsigned long)tid))
+      TM_DBPRT(("%s: INIT daddy tid %lu\n", __func__, (unsigned long)tid))
 
       roots = (struct tm_roots *)ep->e_info;
       roots->tm_parent = new_task(jobid, node, tid);
@@ -1666,7 +1680,7 @@ int tm_poll(
 
       if (ret != DIS_SUCCESS)
         {
-        DBPRT(("%s: SPAWN failed tid\n", id))
+        TM_DBPRT(("%s: SPAWN failed tid\n", __func__))
         goto tm_poll_error;
         }
 
@@ -1684,7 +1698,7 @@ int tm_poll(
 
       if (ret != DIS_SUCCESS)
         {
-        DBPRT(("%s: OBIT failed obitval\n", id))
+        TM_DBPRT(("%s: OBIT failed obitval\n", __func__))
         goto tm_poll_error;
         }
 
@@ -1699,7 +1713,10 @@ int tm_poll(
 
       if (ret != DIS_SUCCESS)
         {
-        DBPRT(("%s: GETINFO failed info\n", id))
+        if (info != NULL)
+          free(info);
+
+        TM_DBPRT(("%s: GETINFO failed info\n", __func__))
         break;
         }
 
@@ -1713,7 +1730,12 @@ int tm_poll(
       info = disrst(static_chan, &ret);
 
       if (ret != DIS_SUCCESS)
+        {
+        if (info != NULL)
+          free(info);
+
         break;
+        }
 
       snprintf(rhold->resc, rhold->len, "%s", info);
 
@@ -1722,13 +1744,16 @@ int tm_poll(
       break;
 
     default:
-      DBPRT(("%s: unknown event command %d\n", id, ep->e_mtype))
+      TM_DBPRT(("%s: unknown event command %d\n", __func__, ep->e_mtype))
       goto tm_poll_error;
     }
 
   DIS_tcp_wflush(static_chan);
 tm_poll_done:
 
+  if (jobid != NULL)
+    free(jobid);
+
   del_event(ep);
   if (tcp_chan_has_data(static_chan) == FALSE)
     {
@@ -1740,6 +1765,9 @@ tm_poll_done:
 
 tm_poll_error:
 
+  if (jobid != NULL)
+    free(jobid);
+
   if (ep)
     del_event(ep);
 
