@@ -99,6 +99,7 @@
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/time.h>
 #include <limits.h>
 #include <time.h>
 #include <fcntl.h>
@@ -164,7 +165,8 @@ static char *class_names[] =
   "Req",
   "Fil",
   "Act",
-  "node"
+  "node",
+  "trqauthd"
   };
 
 /* External functions called */
@@ -357,6 +359,7 @@ int log_open(
 
     if (log_opened < 0)
       {
+      close(fds);
       return(-1);
       }
 
@@ -416,7 +419,6 @@ int job_log_open(
 
   if (job_log_opened > 0)
     {
-    log_err(-1, id, "job log already open");
     return(1); /* already open */
     }
 
@@ -453,6 +455,7 @@ int job_log_open(
 
     if (job_log_opened < 0)
       {
+      close(fds);
       log_err(errno, id, "failed to dup job log file descriptor");
       return(-1);
       }
@@ -509,8 +512,8 @@ void log_err(
  *  log_ext (log extended) - log message to syslog (if available) and to the TORQUE log.
  *
  *  The error is recorded to the TORQUE log file and to syslogd if it is
- *	available.  If the error file has not been opened and if syslog is
- *	not defined, then the console is opened.
+ *  available.  If the error file has not been opened and if syslog is
+ *  not defined, then the console is opened.
 
  *  Note that this function differs from log_err in that you can specify a severity
  *  level that will accompany the message in the syslog (see 'manpage syslog' for a list
@@ -580,6 +583,29 @@ void log_ext(
 
   buf[LOG_BUF_SIZE - 1] = '\0';
 
+  if (!log_mutex)
+    {
+    if (isatty(2))
+      {
+      fprintf(stderr, "%s: %s\n",
+              msg_daemonname,
+              buf);
+      }
+
+#if SYSLOG
+    if (syslogopen == 0)
+      {
+      openlog(msg_daemonname, LOG_NOWAIT, LOG_DAEMON);
+
+      syslogopen = 1;
+      }
+
+    syslog(severity|LOG_DAEMON,"%s",buf);
+#endif /* SYSLOG */
+
+    return;
+    }
+
   pthread_mutex_lock(log_mutex);
 
   if (log_opened == 0)
@@ -709,6 +735,7 @@ int log_job_record(char *buf)
     }
 
   fprintf(joblogfile, "%s\n", buf);
+  fflush(joblogfile);
   pthread_mutex_unlock(job_log_mutex);
 
   return(0);
@@ -743,6 +770,8 @@ void log_record(
   FILE  *savlog;
   char  *start = NULL, *end = NULL;
   size_t nchars;
+  int eventclass = 0;
+  char time_formatted_str[64];
 
   thr_id = syscall(SYS_gettid);
   pthread_mutex_lock(log_mutex);
@@ -771,7 +800,13 @@ void log_record(
       return;
       }
     }
-      
+  
+  time_formatted_str[0] = 0;    
+  log_get_set_eventclass(&eventclass, GETV);
+  if (eventclass == PBS_EVENTCLASS_TRQAUTHD)
+    {
+    log_format_trq_timestamp(time_formatted_str, sizeof(time_formatted_str));
+    }
 
   /*
    * Looking for the newline characters and splitting the output message
@@ -791,7 +826,9 @@ void log_record(
 
     while (tryagain)
       {
-      rc = fprintf(logfile,
+      if (eventclass != PBS_EVENTCLASS_TRQAUTHD)
+        {
+        rc = fprintf(logfile,
               "%02d/%02d/%04d %02d:%02d:%02d;%04x;%10.10s.%d;%s;%s;%s%.*s\n",
               ptm->tm_mon + 1,
               ptm->tm_mday,
@@ -807,7 +844,16 @@ void log_record(
               (text == start ? "" : "[continued]"),
               (int)nchars,
               start);
-
+        }
+      else
+        {
+        rc = fprintf(logfile,
+              "%s %s%.*s\n",
+              time_formatted_str,
+              (text == start ? "" : "[continued]"),
+              (int)nchars,
+              start);
+        }
       if ((rc < 0) &&
           (errno == EPIPE) &&
           (tryagain == 2))
@@ -846,9 +892,12 @@ void log_record(
      * if we can't open this then we're going to have a nice surprise failure */
     if (logfile != NULL)
       {
-      log_err(rc, "log_record", "PBS cannot write to its log");
+      pthread_mutex_unlock(log_mutex);
+      log_err(rc, __func__, "PBS cannot write to its log");
       fclose(logfile);
+      pthread_mutex_lock(log_mutex);
       }
+
     logfile = savlog;
     }
   
@@ -1315,12 +1364,19 @@ long log_size(void)
     {
     /* FAILURE */
 
+    pthread_mutex_unlock(log_mutex);
+    /* log_err through log_ext will lock the log_mutex, so release log_mutex before calling log_err */
     log_err(errno, "log_size", "PBS cannot fstat logfile");
 
-    pthread_mutex_unlock(log_mutex);
     return(0);
     }
   
+  if (!log_opened) {
+      pthread_mutex_unlock(log_mutex);
+      log_err(EAGAIN, "log_size", "PBS cannot find size of log file because logfile has not been opened");
+      return(0);
+  }
+
   pthread_mutex_unlock(log_mutex);
 
   return(file_stat.st_size / 1024);
@@ -1338,7 +1394,8 @@ long job_log_size(void)
 
   struct stat file_stat;
 #endif
-  
+ 
+  memset(&file_stat, 0, sizeof(file_stat));
   pthread_mutex_lock(job_log_mutex);
 
 #if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64) && defined(LARGEFILE_WORKS)
@@ -1350,7 +1407,7 @@ long job_log_size(void)
     {
     /* FAILURE */
 
-    log_err(errno, "log_size", "PBS cannot fstat joblogfile");
+    log_err(errno, __func__, "PBS cannot fstat joblogfile");
     pthread_mutex_unlock(job_log_mutex);
 
     return(0);
@@ -1362,14 +1419,18 @@ long job_log_size(void)
   }
 
 
-void print_trace(int socknum)
+void print_trace(
+    
+  int socknum)
+
   {
-  void *array[10];
-  int size;
+  void  *array[10];
+  int    size;
   char **meth_names;
-  int cntr;
-  char msg[120];
-  char meth_name[20];
+  int    cntr;
+  char   msg[120];
+  char   meth_name[20];
+
   size = backtrace(array, 10);
   meth_names = backtrace_symbols(array, size);
   snprintf(meth_name, sizeof(meth_name), "pt - pos %d", socknum);
@@ -1381,4 +1442,41 @@ void print_trace(int socknum)
     }
   free(meth_names);
   }
+
+
+void log_get_set_eventclass(
+
+  int *objclass, 
+  SGetter action)
+
+  {
+  static int log_objclass = 0;
+
+  if (action == SETV)
+    log_objclass = *objclass;
+  else if (action == GETV)
+    *objclass = log_objclass;
+
+  } /* end of log_get_set_evnetclass */
+
+void log_format_trq_timestamp(
+
+  char *time_formatted_str, 
+  unsigned int buflen)
+
+  {
+  char           buffer[30];
+  struct timeval tv;
+  time_t         curtime;
+  struct tm      result;
+  unsigned int   milisec=0;
+
+  gettimeofday(&tv, NULL); 
+  curtime=tv.tv_sec;
+
+  localtime_r(&curtime, &result);
+  strftime(buffer,30,"%Y-%m-%d %H:%M:%S.", &result);
+  milisec = tv.tv_usec/100;
+  snprintf(time_formatted_str, buflen, "%s%04d", buffer, milisec);
+  } /* end of log_format_trq_timestamp */
 /* END pbs_log.c */
