@@ -68,8 +68,6 @@ int socket_get_tcp()
   int local_socket = 0;
   struct linger l_delay;
   int on = 1;
-  int ka_val = 1;
-  int ka_timeout = 10;
 
   (void) signal(SIGPIPE, SIG_IGN);
   memset(&l_delay, 0, sizeof(struct linger));
@@ -80,25 +78,15 @@ int socket_get_tcp()
     }
   else if (setsockopt(local_socket, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(on)) == -1)
     {
+    close(local_socket);
     local_socket = -3;
     }
   else if (setsockopt(local_socket, SOL_SOCKET, SO_LINGER, &l_delay, sizeof(struct linger)) == -1)
     {
+    close(local_socket);
     local_socket = -4;
     }
-  else if (setsockopt(local_socket, SOL_SOCKET, SO_KEEPALIVE, &ka_val, sizeof(int)) < 0)
-    {
-    local_socket = -5;
-    }
-  else if (setsockopt(local_socket, SOL_TCP, TCP_KEEPIDLE, &ka_timeout, sizeof(int)) < 0)
-    {
-    local_socket = -6;
-    }
-/*  else
-    {
-    socket_read_flush(local_socket);
-    }
-    */
+
   return local_socket;
   } /* END socket_get_tcp() */
 
@@ -113,8 +101,6 @@ int get_listen_socket(
   int local_socket = 0;
   struct linger l_delay;
   int on = 1;
-  int ka_val = 1;
-  int ka_timeout = 10;
   
   (void) signal(SIGPIPE, SIG_IGN);
   memset(&l_delay, 0, sizeof(struct linger));
@@ -126,20 +112,14 @@ int get_listen_socket(
     }
   else if (setsockopt(local_socket, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(on)) == -1)
     {
+    close(local_socket);
     local_socket = -3;
     }
   else if (setsockopt(local_socket, SOL_SOCKET, SO_LINGER, &l_delay, sizeof(struct linger)) == -1)
     {
+    close(local_socket);
     local_socket = -4;
     }
-  else if (setsockopt(local_socket, SOL_SOCKET, SO_KEEPALIVE, &ka_val, sizeof(int)) < 0)
-    {
-    local_socket = -5;
-    }
-  else if (setsockopt(local_socket, SOL_TCP, TCP_KEEPIDLE, &ka_timeout, sizeof(int)) < 0)
-    {
-    local_socket = -6;
-    }
 
   return(local_socket);
   } /* END get_listen_socket() */
@@ -234,7 +214,11 @@ int socket_get_tcp_priv()
         if (++priv_port >= RES_PORT_END)
           priv_port = RES_PORT_START;
         local.sin_port = htons(priv_port);
-        if (((rc = bind(local_socket, (struct sockaddr *)&local, sizeof(struct sockaddr))) < 0) && ((rc == EADDRINUSE) || (errno = EADDRNOTAVAIL) || (errno == EINVAL) || (rc == EINPROGRESS)))
+        if (((rc = bind(local_socket, (struct sockaddr *)&local, sizeof(struct sockaddr))) < 0) &&
+            ((rc == EADDRINUSE) ||
+             (errno == EADDRNOTAVAIL) ||
+             (errno == EINVAL) ||
+             (rc == EINPROGRESS)))
           {
           cntr++;
           }
@@ -451,35 +435,31 @@ int socket_wait_for_read(
   pfd.events = POLLIN | POLLHUP; /* | POLLRDNORM; */
   pfd.revents = 0;
 
-  while (pfd.revents == 0)
+  ret = poll(&pfd, 1, pbs_tcp_timeout * 1000); /* poll's timeout is in milliseconds */
+  if (ret > 0)
     {
-    ret = poll(&pfd, 1, pbs_tcp_timeout * 1000); /* poll's timeout is in milliseconds */
-    if (ret > 0)
+    char buf[8];
+    if (recv(socket, buf, 7, MSG_PEEK | MSG_DONTWAIT) == 0)
       {
-      char buf[8];
-      if (recv(socket, buf, 7, MSG_PEEK | MSG_DONTWAIT) == 0)
-        {
-        /* This will only occur when the socket has closed */
-        rc = PBSE_SOCKET_CLOSE;
-        break;
-        }
-      else
-        break; /* data exists */
+      /* This will only occur when the socket has closed */
+      rc = PBSE_SOCKET_CLOSE;
       }
-    else if (ret == 0)
+    }
+  else if (ret == 0)
+    {
+    /* Server timeout reached */
+    rc = PBSE_TIMEOUT;
+    }
+  else /* something bad happened to poll */
+    {
+    if (pfd.revents & POLLNVAL)
       {
-      /* Server timeout reached */
-      rc = PBSE_TIMEOUT;
-      break;
+      rc = PBSE_SOCKET_CLOSE;
       }
-    else /* something bad happened to poll */
+    else
       rc = PBSE_SOCKET_DATA;
     }
 
-  if (pfd.revents & POLLNVAL)
-    {
-    rc = PBSE_SOCKET_CLOSE;
-    }
 
   return(rc);
   } /* END socket_wait_for_read() */
@@ -599,7 +579,7 @@ int socket_read(
   long long  *str_len)
 
   {
-  int rc = PBSE_NONE;
+  int       rc = PBSE_NONE;
   long long avail_bytes = socket_avail_bytes_on_descriptor(socket);
   long long byte_count = 0;
 
@@ -673,12 +653,14 @@ int socket_read_num(
   long long *the_num)
 
   {
-  int rc =  PBSE_INTERNAL;
-  int pos = 0;
+  int  rc =  PBSE_INTERNAL;
+  int  pos = 0;
   char str_ll[MAX_NUM_LEN];
   char tmp_char = '\0';
-  int avail_bytes = socket_avail_bytes_on_descriptor(socket);
+  int  avail_bytes = socket_avail_bytes_on_descriptor(socket);
+
   memset(str_ll, 0, MAX_NUM_LEN);
+
   while (1)
     {
     if (avail_bytes == 0)
@@ -695,7 +677,7 @@ int socket_read_num(
       }
     else if (read(socket, &tmp_char, 1) == -1)
       break;
-    else if (pos > MAX_NUM_LEN)
+    else if (pos >= (int)sizeof(str_ll) - 1)
       break;
     else if ((tmp_char >= '0' && tmp_char <= '9') || (tmp_char == '-'))
       {
@@ -714,8 +696,10 @@ int socket_read_num(
     else
       break;
     }
-  if (str_ll[0] == 0)
+
+  if (str_ll[0] == '\0')
     rc = PBSE_SOCKET_READ;
+
   return rc;
   } /* END socket_read_num() */
 
