@@ -643,6 +643,37 @@ void free_buckets(
   } /* END free_buckets() */
 
 
+
+
+/* 
+ * NOTE: this should only be called right before a hash table is freed
+ * and *ONLY* if the keys are all OWNED by the hash table and nobody else
+ */
+
+void free_all_keys(
+    
+  hash_table_t *ht) 
+
+  {
+  bucket *b;
+  int     i;
+
+  for (i = 0; i < ht->size; i++)
+    {
+    b = ht->buckets[i];
+
+    while (b != NULL)
+      {
+      free(b->key);
+      b = b->next;
+      }
+    }
+
+  } /* END free_all_keys() */
+
+
+
+
 void free_hash(
 
   hash_table_t *ht)
@@ -662,10 +693,18 @@ int get_hash(
   void         *key)
 
   {
-  size_t   len = strlen(key);
+  size_t   len;
   uint32_t hash;
   uint32_t mask = 0;
-  uint32_t counter = ht->size >> 1;
+  uint32_t counter;
+
+  if (ht == NULL)
+    return(-1);
+  if (key == NULL)
+    return(-1);
+
+  len = strlen(key);
+  counter = ht->size >> 1;
 
 #ifdef HASH_LITTLE_ENDIAN
   hash = hashlittle(key,len,0);
@@ -840,8 +879,19 @@ int get_value_hash(
 
   {
   int     value = -1;
-  bucket *b = ht->buckets[get_hash(ht, key)];
+  int     hash_index;
+  bucket *b;
 
+  if (ht == NULL)
+    return(-1);
+  if (key == NULL)
+    return(-1);
+
+  hash_index = get_hash(ht, key);
+  if (hash_index < 0)
+    return(-1);
+
+  b = ht->buckets[hash_index];
   while (b != NULL)
     {
     if (!strcmp(b->key, key))
