@@ -383,15 +383,26 @@ int process_node(
   snprintf(buf, sizeof(buf), "totmem=%llukb", mem_kb);
   copy_to_end_of_dynamic_string(status, buf);
 
+  snprintf(buf, sizeof(buf), "physmem=%llukb", mem_kb);
+  copy_to_end_of_dynamic_string(status, buf);
+
   if (rsv_id != NULL)
     {
-    copy_to_end_of_dynamic_string(status, "reservation_id=");
-    append_dynamic_string(status, rsv_id);
+    /* don't write the reservation id if we're in interactive mode */
+    if ((role_value == NULL) ||
+        (strcmp(role_value, interactive_caps)))
+      {
+      copy_to_end_of_dynamic_string(status, "reservation_id=");
+      append_dynamic_string(status, rsv_id);
+      }
 
     free(rsv_id);
 
     /* if there's a reservation on this node, the state is busy */
     copy_to_end_of_dynamic_string(status, "state=BUSY");
+    
+    snprintf(buf, sizeof(buf), "availmem=0kb");
+    copy_to_end_of_dynamic_string(status, buf);
     }
   else
     {
@@ -401,14 +412,25 @@ int process_node(
     
     if ((role_value != NULL) &&
         (!strcmp(role_value, interactive_caps)))
+      {
       append_dynamic_string(status, "DOWN");
+      
+      snprintf(buf, sizeof(buf), "availmem=0kb");
+      copy_to_end_of_dynamic_string(status, buf);
+      }
     else
+      {
       append_dynamic_string(status, attr_value);
+     
+      snprintf(buf, sizeof(buf), "availmem=%llukb", mem_kb);
+      copy_to_end_of_dynamic_string(status, buf);
+      }
 
     free(attr_value);
     }
 
-  free(role_value);
+  if (role_value != NULL)
+    free(role_value);
 
   if (features->used > 0)
     {
