@@ -120,6 +120,7 @@
 #include "log.h"
 #include "mom_mach.h"
 #include "resmon.h"
+#include "utils.h"
 #include "../rm_dep.h"
 
 /*
@@ -145,7 +146,7 @@
 **  quota  quota information (sizes in KB)
 */
 
-static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 3230 $";
+static char ident[] = "@(#) sgi/$RCSfile$ $Revision$";
 
 #ifndef TRUE
 #define FALSE 0
@@ -328,9 +329,7 @@ dep_main_loop_cycle(void)
  *  sizeof(word) = sizeof(int)
  */
 
-static int getsize(pres, ret)
-resource  *pres;
-rlim64_t  *ret;
+static int mm_getsize(resource *pres, rlim64_t *ret)
   {
   rlim64_t value;
 
@@ -382,7 +381,7 @@ getlong(resource *pres, unsigned long *ret)
  */
 
 static int
-gettime(resource *pres, unsigned long *ret)
+mm_gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -783,7 +782,7 @@ mom_set_limits(
       if (igncput == FALSE)
         {
         /* cpu time - check, if less than pcput use it */
-        retval = gettime(pres, &value);
+        retval = mm_gettime(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
@@ -794,7 +793,7 @@ mom_set_limits(
       if (igncput == FALSE)
         {
         /* process cpu time - set */
-        retval = gettime(pres, &value);
+        retval = mm_gettime(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
@@ -810,7 +809,7 @@ mom_set_limits(
       {
       if (set_mode == SET_LIMIT_SET)
         {
-        retval = getsize(pres, &sizeval);
+        retval = mm_getsize(pres, &sizeval);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
@@ -825,8 +824,8 @@ mom_set_limits(
       {
       if (ignvmem == FALSE)
         {
-        retval = getsize(pres, &sizeval);
- 
+        retval = mm_getsize(pres, &sizeval);
+
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
@@ -838,8 +837,8 @@ mom_set_limits(
       {
       if (ignvmem == FALSE)
         {
-        retval = getsize(pres, &sizeval);
- 
+        retval = mm_getsize(pres, &sizeval);
+
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
@@ -856,7 +855,7 @@ mom_set_limits(
         {
         if (set_mode == SET_LIMIT_SET)
           {
-          retval = getsize(pres, &sizeval);
+          retval = mm_getsize(pres, &sizeval);
 
           if (retval != PBSE_NONE)
             return (error(pname, retval));
@@ -987,7 +986,7 @@ mom_open_poll(void)
 
   if (proc_array == NULL)
     {
-    log_err(errno, id, "malloc");
+    log_err(errno, id, "calloc");
     return (PBSE_SYSTEM);
     }
 
@@ -1072,7 +1071,7 @@ mom_get_sample(void)
       size_t nb = sizeof(prmap_sgi_t) * num;
 
       assert(num < MAPNUM);
-      pi->map = (prmap_sgi_t *) malloc(nb);
+      pi->map = (prmap_sgi_t *) calloc(1, nb);
       memcpy(pi->map, map, nb);
       pi->map_num = num;
       }
@@ -1209,7 +1208,7 @@ mom_over_limit(job *pjob)
       }
     else if (strcmp(pname, "vmem") == 0)
       {
-      retval = getsize(pres, &sizeval);
+      retval = mm_getsize(pres, &sizeval);
 
       if (retval != PBSE_NONE)
         continue;
@@ -1224,7 +1223,7 @@ mom_over_limit(job *pjob)
       }
     else if (strcmp(pname, "pvmem") == 0)
       {
-      retval = getsize(pres, &sizeval);
+      retval = mm_getsize(pres, &sizeval);
 
       if (retval != PBSE_NONE)
         continue;
@@ -2767,7 +2766,7 @@ quota(struct rm_attribute *attrib)
 
   if ((uid = (uid_t)atoi(attrib->a_value)) == 0)
     {
-    if ((pw = getpwnam(attrib->a_value)) == NULL)
+    if ((pw = getpwnam_ext(attrib->a_value)) == NULL)
       {
       sprintf(log_buffer,
               "user not found: %s", attrib->a_value);
