@@ -130,7 +130,7 @@
 #endif  /* OPEN_MAX */
 
 /* File Scope Variables. Variables available only within this file. */
-static char ident[] = "@(#) $RCSfile$ $Revision: 2367 $";
+static char ident[] = "@(#) $RCSfile$ $Revision$";
 static char     **glob_argv;
 
 static int  alarm_time = 180;
@@ -656,13 +656,10 @@ SystemInit(int argc, char *argv[])
   int  gethostname();
 
 #ifndef DEBUG
-
-  if ((geteuid() != 0) || (getuid() != 0))
+  if (IamRoot() == 0)
     {
-    fprintf(stderr, "%s: Must be run by root\n", argv[0]);
-    exit(1);
+	exit(1);
     }
-
 #endif  /* DEBUG */
 
   if (gethostname(host, sizeof(host)) == -1)
