@@ -235,10 +235,13 @@ int acct_job(
   /* For large clusters strings can get pretty long. We need to see if there
      is a need to allocate a bigger buffer */
   /* execution host name */
-  append_dynamic_string(ds, "exec_host=");
-  append_dynamic_string(ds, pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str);
-  if ((rc = append_dynamic_string(ds, " ")) != PBSE_NONE)
-    return(rc);
+  if (pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str != NULL)
+    {
+    append_dynamic_string(ds, "exec_host=");
+    append_dynamic_string(ds, pjob->ji_wattr[JOB_ATR_exec_host].at_val.at_str);
+    if ((rc = append_dynamic_string(ds, " ")) != PBSE_NONE)
+      return(rc);
+    }
 
   get_svr_attr_l(SRV_ATR_CrayEnabled, &cray_enabled);
   if ((cray_enabled == TRUE) &&
@@ -506,12 +509,13 @@ void account_jobend(
   char *used) /* job usage information, see req_jobobit() */
 
   {
-  time_t              time_now = time(NULL);
   dynamic_string     *ds;
   char                local_buf[MAXLINE * 4];
 #ifdef USESAVEDRESOURCES
   pbs_attribute      *pattr;
   long                walltime_val = 0;
+#else
+  time_t              time_now = time(NULL);
 #endif
 
   /* pack in general information about the job */
