@@ -81,6 +81,7 @@
  * Each legal job pbs_attribute is defined here.
  */
 
+#include <stdlib.h>
 #include <pbs_config.h>		/* the master config generated by configure */
 
 #include "pbs_ifl.h"
@@ -98,6 +99,42 @@ extern int comp_checkpoint (pbs_attribute *, pbs_attribute *);
 
 #define ATR_DFLAG_SSET  (ATR_DFLAG_SvWR | ATR_DFLAG_SvRD)
 
+int encode_exec_host(
+
+  pbs_attribute  *attr,    /* ptr to pbs_attribute */
+  tlist_head     *phead,   /* head of attrlist */
+  char           *atname,  /* name of pbs_attribute */
+  char           *rsname,  /* resource name or null */
+  int             mode,    /* encode mode, unused here */
+  int             perm)    /* only used for resources */
+
+  {
+  char *old_str;
+  char *export_str;
+  char *pipe;
+  int   rc;
+
+  if (attr->at_val.at_str == NULL)
+    return(PBSE_NONE);
+
+  export_str = strdup(attr->at_val.at_str);
+
+  while ((pipe = strchr(export_str, '|')) != NULL)
+    *pipe = '+';
+
+  old_str = attr->at_val.at_str;
+  attr->at_val.at_str = export_str;
+
+  rc = encode_str(attr, phead, atname, rsname, mode, perm);
+  attr->at_val.at_str = old_str;
+  free(export_str);
+
+  return(rc);
+  } /* END encode_exec_host() */
+
+
+
+
 /*
  * The entries for each pbs_attribute are (see attribute.h):
  * name,
@@ -274,7 +311,7 @@ attribute_def job_attr_def[] =
   /* JOB_ATR_exec_host */
   { ATTR_exechost,  /* "exec_host" */
     decode_str,
-    encode_str,
+    encode_exec_host,
     set_str,
     comp_str,
     free_str,
@@ -1134,6 +1171,18 @@ attribute_def job_attr_def[] =
    ATR_TYPE_STR,
    PARENT_TYPE_JOB},
 
+  /* JOB_ATR_multi_req_alps */
+  {ATTR_multi_req_alps, /* "multi_req_alps" */
+   decode_str,
+   encode_str,
+   set_str,
+   comp_str,
+   free_str,
+   NULL_FUNC,
+   READ_WRITE | ATR_DFLAG_MOM,
+   ATR_TYPE_STR,
+   PARENT_TYPE_JOB},
+
   /* Site defined attributes if any, see site_job_attr_*.h  */
 #include "site_job_attr_def.h"
 
