@@ -145,7 +145,6 @@
 #include "dynamic_string.h"
 #include "svr_func.h" /* get_svr_attr_* */
 #include "track_alps_reservations.h"
-#include "req_signal.h" /* issue_signal */
 #include "issue_request.h" /* release_req */
 #include "ji_mutex.h"
 #include "user_info.h"
@@ -169,6 +168,7 @@ extern struct batch_request *setup_cpyfiles(struct batch_request *,job *,char*,c
 extern int job_log_open(char *, char *);
 extern int log_job_record(char *buf);
 extern void check_job_log(struct work_task *ptask);
+int issue_signal(job **, char *, void(*)(batch_request *), void *);
 
 /* Local Private Functions */
 
@@ -413,7 +413,6 @@ int job_abt(
   char  *text)  /* I (optional) */
 
   {
-  char *myid = "job_abt";
   char  log_buf[LOCAL_LOG_BUF_SIZE];
   int   old_state;
   int   old_substate;
@@ -425,15 +424,19 @@ int job_abt(
   job  *pjob = *pjobp;
   strcpy(job_id, pjob->ji_qs.ji_jobid);
 
+  if (LOGLEVEL >= 6)
+    {
+    sprintf(log_buf, "%s", job_id);
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
+
   /* save old state and update state to Exiting */
 
   old_state = pjob->ji_qs.ji_state;
   old_substate = pjob->ji_qs.ji_substate;
 
-
-
   if (LOGLEVEL >= 6)
-    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
   /* notify user of abort if notification was requested */
 
   if (text != NULL)
@@ -457,13 +460,13 @@ int job_abt(
     {
     svr_setjobstate(pjob, JOB_STATE_RUNNING, JOB_SUBSTATE_ABORT, FALSE);
 
-    if ((rc = issue_signal(&pjob, "SIGKILL", release_req, NULL)) != 0)
+    if ((rc = issue_signal(&pjob, "SIGKILL", free_br, NULL)) != 0)
       {
       if (pjob != NULL)
         {
         sprintf(log_buf, msg_abt_err, pjob->ji_qs.ji_jobid, old_substate);
         
-        log_err(-1, myid, log_buf);
+        log_err(-1, __func__, log_buf);
         
         if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
           {
@@ -476,13 +479,14 @@ int job_abt(
         
         if (pjob->ji_wattr[JOB_ATR_depend].at_flags & ATR_VFLAG_SET)
           {
-          depend_on_term(pjob);
+          unlock_ji_mutex(pjob, __func__, "1a",LOGLEVEL);
+          depend_on_term(job_id);
           pjob = svr_find_job(job_id, TRUE);
           }
         
         /* update internal array bookeeping values */
         if ((pjob != NULL) &&
-            (pjob->ji_arraystruct != NULL) &&
+            (pjob->ji_arraystructid[0] != '\0') &&
             (pjob->ji_is_array_template == FALSE))
           {
           job_array *pa = get_jobs_array(&pjob);
@@ -495,12 +499,7 @@ int job_abt(
             update_array_values(pa,old_state,aeTerminate,
                 job_id, job_atr_hold, job_exit_status);
             
-            if (LOGLEVEL >= 7)
-              {
-              sprintf(log_buf, "unlocking ai_mutex: %s", myid);
-              log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, job_id, log_buf);
-              }
-            pthread_mutex_unlock(pa->ai_mutex);
+            unlock_ai_mutex(pa, __func__, "1", LOGLEVEL);
             pjob = svr_find_job(job_id, TRUE);
             }
           }
@@ -520,7 +519,7 @@ int job_abt(
     sprintf(log_buf, msg_abt_err,
       pjob->ji_qs.ji_jobid,
       old_substate);
-    log_err(-1, myid, log_buf);
+    log_err(-1, __func__, log_buf);
     unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
     }
   else
@@ -537,13 +536,14 @@ int job_abt(
     if (pjob->ji_wattr[JOB_ATR_depend].at_flags & ATR_VFLAG_SET)
       {
       strcpy(job_id, pjob->ji_qs.ji_jobid);
-      depend_on_term(pjob);
+      unlock_ji_mutex(pjob, __func__, "1b", LOGLEVEL);
+      depend_on_term(job_id);
       pjob = svr_find_job(job_id, TRUE);
       }
 
     /* update internal array bookeeping values */
     if ((pjob != NULL) &&
-        (pjob->ji_arraystruct != NULL) &&
+        (pjob->ji_arraystructid[0] != '\0') &&
         (pjob->ji_is_array_template == FALSE))
       {
       job_array *pa = get_jobs_array(&pjob);
@@ -556,12 +556,7 @@ int job_abt(
         update_array_values(pa,old_state,aeTerminate,
             job_id, job_atr_hold, job_exit_status);
         
-        if (LOGLEVEL >= 7)
-          {
-          sprintf(log_buf, "unlocking ai_mutex: %s", myid);
-          log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, job_id, log_buf);
-          }
-        pthread_mutex_unlock(pa->ai_mutex);
+        unlock_ai_mutex(pa, __func__, "1", LOGLEVEL);
         pjob = svr_find_job(job_id, TRUE);
         }
       }
@@ -676,7 +671,6 @@ job *job_alloc(void)
   pj->ji_qs.qs_version = PBS_QS_VERSION;
 
   CLEAR_HEAD(pj->ji_rejectdest);
-  pj->ji_arraystruct = NULL;
   pj->ji_is_array_template = FALSE;
 
   pj->ji_momhandle = -1;  /* mark mom connection invalid */
@@ -840,7 +834,6 @@ job *job_clone(
   char           basename[PBS_JOBBASE+1];
   char           namebuf[MAXPATHLEN + 1];
   char           buf[256];
-  char          *pc;
   int            fds;
 
   int            i;
@@ -890,13 +883,17 @@ job *job_clone(
   hostname = index(oldid, '.');
 
   *bracket = '\0';
-  hostname++;
-
-  pnewjob->ji_qs.ji_jobid[PBS_MAXSVRJOBID-1] = '\0';
-
-  snprintf(pnewjob->ji_qs.ji_jobid, PBS_MAXSVRJOBID, "%s[%d].%s",
-    oldid, taskid, hostname);
-
+  if (hostname != NULL)
+    {
+    hostname++;
+    snprintf(pnewjob->ji_qs.ji_jobid, sizeof(pnewjob->ji_qs.ji_jobid), 
+      "%s[%d].%s",
+      oldid, taskid, hostname);
+    }
+  else
+    snprintf(pnewjob->ji_qs.ji_jobid, sizeof(pnewjob->ji_qs.ji_jobid),
+      "%s[%d]",
+      oldid, taskid);
 
   /* update the job filename
    * We could optimize the sub-jobs to all use the same file. We would need a
@@ -908,7 +905,11 @@ job *job_clone(
    * make up new job file name, it is based on the new jobid
    */
 
-  snprintf(basename, PBS_JOBBASE, "%s-%d.%s", oldid, taskid, hostname);
+  if (hostname != NULL)
+    snprintf(basename, sizeof(basename), "%s-%d.%s", oldid, taskid, hostname);
+  else
+    snprintf(basename, sizeof(basename), "%s-%d", oldid, taskid);
+
   free(oldid);
 
   do
@@ -922,24 +923,8 @@ job *job_clone(
       {
       if (errno == EEXIST)
         {
-        pc = basename + strlen(basename) - 1;
-
-        while (!isprint((int)*pc) || (*pc == '-'))
-          {
-          pc--;
-
-          if (pc <= basename)
-            {
-            /* FAILURE */
-
-            log_err(errno, __func__, "job file is corrupt");
-            job_free(pnewjob, FALSE);
-
-            return(NULL);
-            }
-          }
-
-        (*pc)++;
+        job_free(pnewjob, FALSE);
+        return((job *)1);
         }
       else
         {
@@ -1049,16 +1034,11 @@ job *job_clone(
     }
 
   pa->job_ids[taskid] = strdup(pnewjob->ji_qs.ji_jobid);
-  pnewjob->ji_arraystruct = pa;
+  strcpy(pnewjob->ji_arraystructid, pa->ai_qs.parent_id);
 
   if (release_mutex == TRUE)
     {
-    pthread_mutex_unlock(pa->ai_mutex);
-    if (LOGLEVEL >= 7)
-      {
-      sprintf(log_buf, "unlocked ai_mutex: %s", __func__);
-      log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pnewjob->ji_qs.ji_jobid, log_buf);
-      }
+    unlock_ai_mutex(pa, __func__, "1", LOGLEVEL);
     }
 
   return(pnewjob);
@@ -1081,7 +1061,6 @@ void *job_clone_wt(
   void *cloned_id)
 
   {
-  char                log_buf[LOCAL_LOG_BUF_SIZE];
   job                *template_job;
   job                *pjob;
   job                *pjobclone;
@@ -1094,6 +1073,7 @@ void *job_clone_wt(
   int                 newsub;
   int                 rc;
   char                namebuf[MAXPATHLEN];
+  char                arrayid[PBS_MAXSVRJOBID + 1];
   job_array          *pa;
 
   array_request_node *rn;
@@ -1119,6 +1099,8 @@ void *job_clone_wt(
     return(NULL);
     }
 
+  strcpy(arrayid, pa->ai_qs.parent_id);
+
   free(jobid);
 
   snprintf(namebuf, sizeof(namebuf), "%s%s.AR",
@@ -1132,6 +1114,14 @@ void *job_clone_wt(
 
     for (i = start; i <= end; i++)
       {
+      if (pa->job_ids[i] != NULL)
+        {
+        /* This job already exists. This can happen when trying to recover a job
+         * array that wasn't fully cloned. */
+        rn->start++;
+        continue;
+        }
+
       lock_ji_mutex(template_job, __func__, NULL, LOGLEVEL);
       pjobclone = job_clone(template_job, pa, i);
       unlock_ji_mutex(template_job, __func__, "3", LOGLEVEL);
@@ -1141,6 +1131,12 @@ void *job_clone_wt(
         log_err(-1, __func__, "unable to clone job in job_clone_wt");
         continue;
         }
+      else if (pjobclone == (job *)1)
+        {
+        /* this happens if we attempted to clone an existing job */
+        rn->start++;
+        continue;
+        }
 
       svr_evaljobstate(pjobclone, &newstate, &newsub, 1);
 
@@ -1157,21 +1153,23 @@ void *job_clone_wt(
       if ((rc = svr_enquejob(pjobclone, FALSE, prev_index)))
         {
         /* XXX need more robust error handling */
-        pthread_mutex_unlock(pa->ai_mutex);
+        unlock_ai_mutex(pa, __func__, "1", LOGLEVEL);
 
         if (rc != PBSE_JOB_RECYCLED)
           svr_job_purge(pjobclone);
 
-        pthread_mutex_lock(pa->ai_mutex);
+        pa = get_array(arrayid);
         continue;
         }
 
       if (job_save(pjobclone, SAVEJOB_FULL, 0) != 0)
         {
         /* XXX need more robust error handling */
-        pthread_mutex_unlock(pa->ai_mutex);
+        unlock_ai_mutex(pa, __func__, "2", LOGLEVEL);
         svr_job_purge(pjobclone);
-        pthread_mutex_lock(pa->ai_mutex);
+       
+        pa = get_array(arrayid);
+        
         continue;
         }
       
@@ -1241,13 +1239,7 @@ void *job_clone_wt(
       }
     }
 
-  if (LOGLEVEL >= 7)
-    {
-    sprintf(log_buf, "unlocked ai_mutex: %s", __func__);
-    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pa->ai_qs.parent_id, log_buf);
-    }
-  
-  pthread_mutex_unlock(pa->ai_mutex);
+  unlock_ai_mutex(pa, __func__, "3", LOGLEVEL);
   return(NULL);
   }  /* END job_clone_wt */
 
@@ -1461,7 +1453,7 @@ void remove_checkpoint(
     preq->rq_extra = NULL;
     /* The preq is freed in relay_to_mom (failure)
      * or in issue_Drequest (success) */
-    if (relay_to_mom(&pjob, preq, release_req) == 0)
+    if (relay_to_mom(&pjob, preq, NULL) == PBSE_NONE)
       {
       if (pjob != NULL)
         pjob->ji_qs.ji_svrflags &= ~JOB_SVFLG_CHECKPOINT_COPIED;
@@ -1476,6 +1468,8 @@ void remove_checkpoint(
         pjob->ji_qs.ji_jobid,
         "unable to remove checkpoint file for job");
       }
+
+    free_br(preq);
     }
 
   return;
@@ -1546,19 +1540,22 @@ int record_jobinfo(
   append_dynamic_string(buffer, "<Jobinfo>\n");
   append_dynamic_string(buffer, "\t<Job_Id>");
   append_dynamic_string(buffer, pjob->ji_qs.ji_jobid);
-  append_dynamic_string(buffer, "</JobId>");
-  
+  append_dynamic_string(buffer, "</JobId>\n");
+ 
+ #if 0
   if ((rc = log_job_record(buffer->str)) != PBSE_NONE)
     {
     log_err(rc, __func__, "log_job_record failed");
     free_dynamic_string(buffer);
     return(rc);
     }
+#endif
 
   for (i = 0; i < JOB_ATR_LAST; i++)
     {
+#if 0
     clear_dynamic_string(buffer);
-
+#endif
     pattr = &(pjob->ji_wattr[i]);
 
     if (pattr->at_flags & ATR_VFLAG_SET)
@@ -1584,14 +1581,16 @@ int record_jobinfo(
 
       append_dynamic_string(buffer, "</");
       append_dynamic_string(buffer, job_attr_def[i].at_name);
-      append_dynamic_string(buffer, ">");
+      append_dynamic_string(buffer, ">\n");
 
+#if 0
       if ((rc = log_job_record(buffer->str)) != PBSE_NONE)
         {
         log_err(rc, __func__, "log_job_record failed recording attributes");
         free_dynamic_string(buffer);
         return(rc);
         }
+#endif
       }
     }
   
@@ -1606,13 +1605,14 @@ int record_jobinfo(
     snprintf(namebuf, sizeof(namebuf), "%s%s%s",
       path_jobs, pjob->ji_qs.ji_fileprefix, JOB_SCRIPT_SUFFIX);
     
-    if ((fd = open(namebuf, O_RDONLY)) > 0)
+    if ((fd = open(namebuf, O_RDONLY)) >= 0)
       {
-      while ((bytes_read = read(fd, job_script_buf, sizeof(job_script_buf))) > 0)
+      memset(job_script_buf, 0, sizeof(job_script_buf));
+
+      while ((bytes_read = read(fd, job_script_buf, sizeof(job_script_buf) - 1)) > 0)
         {
-        job_script_buf[bytes_read] = '\0';
-        
         rc = append_dynamic_string(buffer, job_script_buf);
+        memset(job_script_buf, 0, sizeof(job_script_buf));
         }
 
       close(fd);
@@ -1624,15 +1624,19 @@ int record_jobinfo(
    
     append_dynamic_string(buffer, "\t</job_script>\n");
     
+#if 0
     if ((rc = log_job_record(buffer->str)) != PBSE_NONE)
       {
       free_dynamic_string(buffer);
       log_err(rc, __func__, "log_job_record failed");
       return(rc);
       }
+#endif
     }
-  
+ 
+#if 0
   clear_dynamic_string(buffer);
+#endif
 
   if ((rc = append_dynamic_string(buffer, "</Jobinfo>\n")) != PBSE_NONE)
     {
@@ -1676,12 +1680,15 @@ int svr_job_purge(
   int           job_is_array_template;
   unsigned int  job_has_checkpoint_file;
   int           job_has_arraystruct;
+  int           do_delete_array = FALSE;
+  job_array     *pa = NULL;
+  char          array_id[PBS_MAXSVRJOBID+1];
  
   strcpy(job_id, pjob->ji_qs.ji_jobid);
   strcpy(job_fileprefix, pjob->ji_qs.ji_fileprefix);
   job_substate = pjob->ji_qs.ji_substate;
   job_is_array_template = pjob->ji_is_array_template;
-  job_has_arraystruct = ((pjob->ji_arraystruct == NULL)?FALSE:TRUE);
+  job_has_arraystruct = ((pjob->ji_arraystructid[0] == '\0') ? FALSE:TRUE);
   job_has_checkpoint_file = pjob->ji_wattr[JOB_ATR_checkpoint_name].at_flags;
 
   if (LOGLEVEL >= 10)
@@ -1720,34 +1727,34 @@ int svr_job_purge(
     {
     /* pa->ai_mutex will come out locked after 
        the call to get_jobs_array */
-    job_array *pa = get_jobs_array(&pjob);
+    pa = get_jobs_array(&pjob);
 
     if (pjob != NULL)
       {
       /* erase the pointer to this job in the job array */
-      if (pa->job_ids != NULL)
+      if (pa != NULL)
         {
-        free(pa->job_ids[pjob->ji_wattr[JOB_ATR_job_array_id].at_val.at_long]);
-        pa->job_ids[pjob->ji_wattr[JOB_ATR_job_array_id].at_val.at_long] = NULL;
-        }
-      
-      /* if there are no more jobs in the array,
-       * then we can clean that up too */
-      pa->ai_qs.num_purged++;
-      if (pa->ai_qs.num_purged == pa->ai_qs.num_jobs)
-        {
-        /* array_delete will unlock pa->ai_mutex */
-        array_delete(pa);
-        }
-      else
-        {
-        array_save(pa);
-        
-        pthread_mutex_unlock(pa->ai_mutex);
-        if (LOGLEVEL >=7)
+        if (pa->job_ids != NULL)
           {
-          sprintf(log_buf, "unlocked ai_mutex: %s", __func__);
-          log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
+          free(pa->job_ids[pjob->ji_wattr[JOB_ATR_job_array_id].at_val.at_long]);
+          pa->job_ids[pjob->ji_wattr[JOB_ATR_job_array_id].at_val.at_long] = NULL;
+          }
+        
+        /* if there are no more jobs in the array,
+         * then we can clean that up too */
+        pa->ai_qs.num_purged++;
+        if (pa->ai_qs.num_purged == pa->ai_qs.num_jobs)
+          {
+          /* array_delete will unlock pa->ai_mutex */
+          strcpy(array_id, pjob->ji_arraystructid);
+          do_delete_array = TRUE;
+          unlock_ai_mutex(pa, __func__, "1a", LOGLEVEL);
+          }
+        else
+          {
+          array_save(pa);
+          
+          unlock_ai_mutex(pa, __func__, "1", LOGLEVEL);
           }
         }
       }
@@ -1763,12 +1770,10 @@ int svr_job_purge(
     {
     int need_deque = !pjob->ji_cold_restart;
 
-    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-
     /* jobs that are being deleted after a cold restart
      * haven't been queued */
     if (need_deque == TRUE)
-      rc = svr_dequejob(job_id, FALSE);
+      rc = svr_dequejob(pjob, FALSE);
 
     if (rc != PBSE_JOBNOTFOUND)
       {
@@ -1888,6 +1893,13 @@ int svr_job_purge(
     log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_JOB, job_id, log_buf);
     }
 
+  if (do_delete_array == TRUE)
+    {
+    pa = get_array(array_id);
+    if (pa != NULL)
+      array_delete(pa);
+    }
+
   return(PBSE_NONE);
   }  /* END svr_job_purge() */
 
@@ -2125,7 +2137,7 @@ job *find_job_by_array(
   job *pj = NULL;
   int  i;
 
-  pthread_mutex_lock(aj->alljobs_mutex);
+  lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
   
   i = get_value_hash(aj->ht, job_id);
   
@@ -2134,7 +2146,7 @@ job *find_job_by_array(
   if (pj != NULL)
     lock_ji_mutex(pj, __func__, NULL, LOGLEVEL);
   
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
   
   if (pj != NULL)
     {
@@ -2181,6 +2193,7 @@ job *svr_find_job(
   char *comp;
   int   different = FALSE;
   char *dash = NULL;
+  char *dot = NULL;
   char  without_dash[PBS_MAXSVRJOBID + 1];
 
   job  *pj = NULL;
@@ -2196,12 +2209,18 @@ job *svr_find_job(
    * the get the external sub-job */
   if (get_subjob == TRUE)
     {
-    if ((dash = strchr(jobid, '-')) != NULL)
+    dot = strchr(jobid, '.');
+
+    if (((dash = strchr(jobid, '-')) != NULL) &&
+        (dot != NULL) &&
+        (dash < dot))
       {
       *dash = '\0';
       snprintf(without_dash, sizeof(without_dash), "%s%s", jobid, dash + 2);
       jobid = without_dash;
       }
+    else
+      dash = NULL;
     }
 
   if ((is_svr_attr_set(SRV_ATR_display_job_server_suffix)) ||
@@ -2306,7 +2325,7 @@ int insert_job(
   {
   int           rc;
 
-  pthread_mutex_lock(aj->alljobs_mutex);
+  lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   if ((rc = insert_thing(aj->ra,pjob)) == -1)
     {
@@ -2320,7 +2339,7 @@ int insert_job(
     rc = PBSE_NONE;
     }
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   return(rc);
   } /* END insert_job() */
@@ -2346,7 +2365,7 @@ int insert_job_after(
   int rc;
   int i;
 
-  pthread_mutex_lock(aj->alljobs_mutex);
+  lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   i = get_value_hash(aj->ht,already_in->ji_qs.ji_jobid);
   
@@ -2366,7 +2385,7 @@ int insert_job_after(
       }
     }
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   return(rc);
   } /* END insert_job_after() */
@@ -2383,7 +2402,7 @@ int insert_job_after_index(
   {
   int rc;
 
-  pthread_mutex_lock(aj->alljobs_mutex);
+  lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   if ((rc = insert_thing_after(aj->ra, pjob, index)) == -1)
     {
@@ -2396,7 +2415,7 @@ int insert_job_after_index(
     rc = PBSE_NONE;
     }
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   return(rc);
   } /* END insert_job_after_index() */
@@ -2415,7 +2434,7 @@ int insert_job_first(
   {
   int          rc;
 
-  pthread_mutex_lock(aj->alljobs_mutex);
+  lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   if ((rc = insert_thing_after(aj->ra,pjob,ALWAYS_EMPTY_INDEX)) == -1)
     {
@@ -2428,7 +2447,7 @@ int insert_job_first(
     rc = PBSE_NONE;
     }
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   return(rc);
   } /* END insert_job_first () */
@@ -2451,19 +2470,19 @@ int get_jobs_index(
   if (pthread_mutex_trylock(aj->alljobs_mutex))
     {
     unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-    pthread_mutex_lock(aj->alljobs_mutex);
+    lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
     lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
     if (pjob->ji_being_recycled == TRUE)
       {
-      pthread_mutex_unlock(aj->alljobs_mutex);
+      unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
       unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
       return(-1);
       }
     }
 
   index = get_value_hash(aj->ht, pjob->ji_qs.ji_jobid);
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   return(index);
   } /* END get_jobs_index() */
@@ -2489,12 +2508,12 @@ int has_job(
   if (pthread_mutex_trylock(aj->alljobs_mutex))
     {
     unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-    pthread_mutex_lock(aj->alljobs_mutex);
+    lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
     lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
     if (pjob->ji_being_recycled == TRUE)
       {
-      pthread_mutex_unlock(aj->alljobs_mutex);
+      unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
       unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
       return(PBSE_JOB_RECYCLED);
@@ -2506,7 +2525,7 @@ int has_job(
   else
     rc = TRUE;
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   return(rc);
   } /* END has_job() */
@@ -2530,18 +2549,30 @@ int  remove_job(
   {
   int rc = PBSE_NONE;
   int index;
+  char log_buf[LOCAL_LOG_BUF_SIZE];
 
   if (LOGLEVEL >= 10)
-    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
-  if (pthread_mutex_trylock(aj->alljobs_mutex))
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
+
+  rc = pthread_mutex_trylock(aj->alljobs_mutex);
+  if (rc != 0)
     {
     unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-    pthread_mutex_lock(aj->alljobs_mutex);
+    lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
     lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
+    if (LOGLEVEL >= 7)
+      {
+      sprintf(log_buf, "trylock failed: %d", rc);
+      log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+      }
+    rc = PBSE_NONE;
+     
+    
+
     if (pjob->ji_being_recycled == TRUE)
       {
-      pthread_mutex_unlock(aj->alljobs_mutex);
+      unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
       unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       return(PBSE_JOB_RECYCLED);
       }
@@ -2555,7 +2586,7 @@ int  remove_job(
     remove_hash(aj->ht,pjob->ji_qs.ji_jobid);
     }
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   return(rc);
   } /* END remove_job() */
@@ -2574,11 +2605,11 @@ job *next_job(
   char log_buf[LOCAL_LOG_BUF_SIZE];
   int  last_index = *iter;
 
-  pthread_mutex_lock(aj->alljobs_mutex);
+  lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   pjob = (job *)next_thing(aj->ra,iter);
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   if (pjob != NULL)
     {
@@ -2614,13 +2645,13 @@ job *next_job_from_back(
   {
   job *pjob;
 
-  pthread_mutex_lock(aj->alljobs_mutex);
+  lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   pjob = (job *)next_thing_from_back(aj->ra,iter);
   if (pjob != NULL)
     lock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   if (pjob != NULL)
     {
@@ -2655,7 +2686,7 @@ int swap_jobs(
     aj = &alljobs;
     }
 
-  pthread_mutex_lock(aj->alljobs_mutex);
+  lock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
 
   new2 = get_value_hash(aj->ht,job1->ji_qs.ji_jobid);
   new1 = get_value_hash(aj->ht,job2->ji_qs.ji_jobid);
@@ -2673,7 +2704,7 @@ int swap_jobs(
     change_value_hash(aj->ht,job2->ji_qs.ji_jobid,new2);
     }
 
-  pthread_mutex_unlock(aj->alljobs_mutex);
+  unlock_alljobs_mutex(aj, __func__, NULL, LOGLEVEL);
   
   return(rc);
   } /* END swap_jobs() */
@@ -2693,36 +2724,31 @@ job_array *get_jobs_array(
 
   {
   char       log_buf[LOCAL_LOG_BUF_SIZE];
-  char       jobid[PBS_MAXSVRJOBID];
+  char       jobid[PBS_MAXSVRJOBID + 1];
+  char       arrayid[PBS_MAXSVRJOBID + 1];
   job       *pjob = *pjob_ptr;
-  job_array *pa = pjob->ji_arraystruct;
+  job_array *pa = NULL;
 
-  if (pa != NULL)
+  strcpy(jobid, pjob->ji_qs.ji_jobid);
+
+  if (pjob->ji_arraystructid[0] != '\0')
     {
-    if (pthread_mutex_trylock(pa->ai_mutex))
+    strcpy(arrayid, pjob->ji_arraystructid);
+    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+   
+    if (LOGLEVEL >= 7)
       {
-      strcpy(jobid, pjob->ji_qs.ji_jobid);
-      
-      unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-      if (LOGLEVEL >=7)
-        {
-        sprintf(log_buf, "locking ai_mutex: %s", __func__);
-        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, jobid, log_buf);
-        }
+      sprintf(log_buf, "Locking ai_mutex, %s", pjob->ji_qs.ji_jobid);
+      log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+      }
 
-      pthread_mutex_lock(pa->ai_mutex);
-      if (LOGLEVEL >=7)
-        {
-        sprintf(log_buf, "locked ai_mutex: %s", __func__);
-        log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, jobid, log_buf);
-        }
+    pa = get_array(arrayid);
       
-      if ((pjob = svr_find_job(jobid, TRUE)) == NULL)
-        {
-        pthread_mutex_unlock(pa->ai_mutex);
-        pa = NULL;
-        *pjob_ptr = NULL;
-        }
+    if ((pjob = svr_find_job(jobid, TRUE)) == NULL)
+      {
+      unlock_ai_mutex(pa, __func__, "1", LOGLEVEL);
+      pa = NULL;
+      *pjob_ptr = NULL;
       }
     }
 
@@ -2739,6 +2765,9 @@ pbs_queue *get_jobs_queue(
   job       *pjob = *pjob_ptr;
   pbs_queue *pque;
 
+  if (LOGLEVEL >= 10)
+    log_event(PBSEVENT_DEBUG, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
+
   pque = lock_queue_with_job_held(pjob->ji_qhdr, pjob_ptr);
 
   return(pque);
