@@ -127,7 +127,6 @@ extern char     *msg_err_unlink;
 extern char *path_queues;
 
 extern struct    server server;
-extern all_queues svr_queues;
 extern queue_recycler q_recycler;
 
 int lock_queue(
@@ -138,7 +137,7 @@ int lock_queue(
   int               logging)
 
   {
-  int rc = PBSE_NONE;
+  int   rc = PBSE_NONE;
   char *err_msg = NULL;
 
   if (logging >= 10)
@@ -149,15 +148,15 @@ int lock_queue(
     }
 
   if (pthread_mutex_lock(the_queue->qu_mutex) != 0)
-    { 
-    if (logging >= 10) 
+    {
+    if (logging >= 10)
       {
       snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot lock queue %s mutex in method %s",
           the_queue->qu_qs.qu_name, id);
       log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, __func__, err_msg);
       }
     rc = PBSE_MUTEX;
-    } 
+    }
 
   if (err_msg != NULL)
     free(err_msg);
@@ -203,6 +202,75 @@ int unlock_queue(
   return rc;
   }
 
+int lock_allques_mutex(
+
+  all_queues       *all_ques,
+  const char       *id,
+  char             *msg,
+  int               logging)
+
+  {
+  int rc = PBSE_NONE;
+  char *err_msg = NULL;
+
+  if (logging >= 10)
+    { 
+    err_msg = (char *)calloc(1, MSG_LEN_LONG);
+    snprintf(err_msg, MSG_LEN_LONG, "locking allques_mutex in method %s", id);
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_QUEUE, __func__, err_msg);
+    }
+
+  if (pthread_mutex_lock(all_ques->allques_mutex) != 0)
+    { 
+    if (logging >= 10) 
+      {
+      snprintf(err_msg, MSG_LEN_LONG, "alert: cannot lock allques_mutex in method %s", id);
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_QUEUE, __func__, err_msg);
+      }
+    rc = PBSE_MUTEX;
+    } 
+
+  if (err_msg != NULL)
+    free(err_msg);
+
+  return rc;
+  }
+
+int unlock_allques_mutex(
+
+  all_queues       *all_ques,
+  const char       *id,
+  char             *msg,
+  int               logging)
+
+  {
+  int rc = PBSE_NONE;
+  char *err_msg = NULL;
+
+  if (logging >= 10)
+    { 
+    err_msg = (char *)calloc(1, MSG_LEN_LONG);
+    snprintf(err_msg, MSG_LEN_LONG, "unlocking allques_mutex in method %s", id);
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, __func__, err_msg);
+    }
+
+  if (pthread_mutex_unlock(all_ques->allques_mutex) != 0)
+    { 
+    if (logging >= 10) 
+      {
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot unlock allques_mutex in method %s", id);
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, __func__, err_msg);
+      }
+    rc = PBSE_MUTEX;
+    } 
+
+  if (err_msg != NULL)
+    free(err_msg);
+
+  return rc;
+  }
+
+
 
 /*
  * que_alloc - allocate space for a queue structure and initialize
@@ -250,7 +318,7 @@ pbs_queue *que_alloc(
   pthread_mutex_init(pq->qu_mutex,NULL);
   lock_queue(pq, __func__, NULL, LOGLEVEL);
 
-  strncpy(pq->qu_qs.qu_name, name, PBS_MAXQUEUENAME);
+  snprintf(pq->qu_qs.qu_name, sizeof(pq->qu_qs.qu_name), "%s", name);
 
   insert_queue(&svr_queues,pq);
  
@@ -395,7 +463,7 @@ pbs_queue *find_queuebyname(
   if (pc != NULL)
     *pc = '\0';
 
-  pthread_mutex_lock(svr_queues.allques_mutex);
+  lock_allques_mutex(&svr_queues, __func__, NULL, LOGLEVEL);
 
   i = get_value_hash(svr_queues.ht,qname);
 
@@ -407,7 +475,7 @@ pbs_queue *find_queuebyname(
   if (pque != NULL)
     lock_queue(pque, __func__, NULL, LOGLEVEL);
 
-  pthread_mutex_unlock(svr_queues.allques_mutex);
+  unlock_allques_mutex(&svr_queues, __func__, NULL, LOGLEVEL);
   
   if (pque != NULL)
     {
@@ -485,7 +553,7 @@ int insert_queue(
   {
   int          rc;
 
-  pthread_mutex_lock(aq->allques_mutex);
+  lock_allques_mutex(aq, __func__, NULL, LOGLEVEL);
 
   if ((rc = insert_thing(aq->ra,pque)) == -1)
     {
@@ -498,7 +566,7 @@ int insert_queue(
     rc = PBSE_NONE;
     }
 
-  pthread_mutex_unlock(aq->allques_mutex);
+  unlock_allques_mutex(aq, __func__, NULL, LOGLEVEL);
 
   return(rc);
   } /* END insert_queue() */
@@ -520,7 +588,7 @@ int remove_queue(
   if (pthread_mutex_trylock(aq->allques_mutex))
     {
     unlock_queue(pque, __func__, NULL, LOGLEVEL);
-    pthread_mutex_lock(aq->allques_mutex);
+    lock_allques_mutex(aq, __func__, "1", LOGLEVEL);
     lock_queue(pque, __func__, NULL, LOGLEVEL);
     }
 
@@ -535,7 +603,7 @@ int remove_queue(
   snprintf(log_buf, sizeof(log_buf), "index = %d, name = %s", index, pque->qu_qs.qu_name);
   log_err(-1, __func__, log_buf);
 
-  pthread_mutex_unlock(aq->allques_mutex);
+  unlock_allques_mutex(aq, __func__, "2", LOGLEVEL);
 
   return(rc);
   } /* END remove_queue() */
@@ -552,12 +620,12 @@ pbs_queue *next_queue(
   {
   pbs_queue *pque;
 
-  pthread_mutex_lock(aq->allques_mutex);
+  lock_allques_mutex(aq, __func__, NULL, LOGLEVEL);
 
   pque = (pbs_queue *)next_thing(aq->ra,iter);
   if (pque != NULL)
     lock_queue(pque, "next_queue", NULL, LOGLEVEL);
-  pthread_mutex_unlock(aq->allques_mutex);
+  unlock_allques_mutex(aq, __func__, NULL, LOGLEVEL);
 
   if (pque != NULL)
     {
@@ -574,102 +642,22 @@ pbs_queue *next_queue(
 
 
 
-/* 
- * gets the locks on both queues without releasing the all_queues mutex lock.
- * Doing this another way can cause deadlock.
- *
- * @return PBSE_NONE on success
- */
-
-int get_parent_dest_queues(
-
-  char       *queue_parent_name,
-  char       *queue_dest_name,
-  pbs_queue **parent,
-  pbs_queue **dest,
-  job       **pjob_ptr)
-
-  {
-  pbs_queue *pque_parent;
-  pbs_queue *pque_dest;
-  char       jobid[PBS_MAXSVRJOBID + 1];
-  char       log_buf[LOCAL_LOG_BUF_SIZE + 1];
-  job       *pjob = *pjob_ptr;
-  int        index_parent;
-  int        index_dest;
-  int        rc = PBSE_NONE;
-
-  if (LOGLEVEL >= 7)
-    {
-    sprintf(log_buf, "%s", pjob->ji_qs.ji_jobid);
-    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
-    }
-
-  strcpy(jobid, pjob->ji_qs.ji_jobid);
-  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-
-  unlock_queue(*parent, __func__, NULL, 0);
-
-  *parent = NULL;
-  *dest   = NULL;
-
-  pthread_mutex_lock(svr_queues.allques_mutex);
-
-  index_parent = get_value_hash(svr_queues.ht, queue_parent_name);
-  index_dest   = get_value_hash(svr_queues.ht, queue_dest_name);
-
-  if ((index_parent < 0) ||
-      (index_dest < 0))
-    {
-    rc = -1;
-    }
-  else
-    {
-    /* good path */
-    pque_parent = svr_queues.ra->slots[index_parent].item;
-    pque_dest   = svr_queues.ra->slots[index_dest].item;
-
-    if ((pque_parent == NULL) ||
-        (pque_dest == NULL))
-      {
-      rc = -1;
-      }
-    else
-      {
-      /* SUCCESS! */
-      lock_queue(pque_parent, __func__, NULL, 0);
-      lock_queue(pque_dest,   __func__, NULL, 0);
-      *parent = pque_parent;
-      *dest = pque_dest;
-
-      rc = PBSE_NONE;
-      }
-    }
-
-  pthread_mutex_unlock(svr_queues.allques_mutex);
-
-  if ((*pjob_ptr = svr_find_job(jobid, TRUE)) == NULL)
-    rc = -1;
-
-  return(rc);
-  } /* END get_parent_dest_queues() */
-
-
-
-
-
 pbs_queue *lock_queue_with_job_held(
 
   pbs_queue  *pque,
   job       **pjob_ptr)
 
   {
-  char       jobid[PBS_MAXSVRJOBID];
+  char       jobid[PBS_MAXSVRJOBID + 1];
   job       *pjob = *pjob_ptr;
+  int        rc = PBSE_NONE;
 
   if (pque != NULL)
     {
-    if (pthread_mutex_trylock(pque->qu_mutex))
+    if (LOGLEVEL >= 10 )
+      log_event(PBSEVENT_DEBUG, PBS_EVENTCLASS_QUEUE, __func__, pque->qu_qs.qu_name);
+    rc = pthread_mutex_trylock(pque->qu_mutex);
+    if (rc != 0)
       {
       /* if fail */
       strcpy(jobid, pjob->ji_qs.ji_jobid);
@@ -678,7 +666,7 @@ pbs_queue *lock_queue_with_job_held(
 
       if ((pjob = svr_find_job(jobid, TRUE)) == NULL)
         {
-        unlock_queue(pque, __func__, NULL, 0);
+        unlock_queue(pque, __func__, NULL, LOGLEVEL);
         pque = NULL;
         *pjob_ptr = NULL;
         }
