@@ -145,7 +145,6 @@
 
 extern int            LOGLEVEL;
 extern struct server  server;
-extern all_queues     svr_queues;
 extern attribute_def  que_attr_def[];
 extern attribute_def  svr_attr_def[];
 extern attribute_def  node_attr_def[];   /* node attributes defs */
@@ -1244,7 +1243,11 @@ void mgr_server_set(
         continue;
         }
 
-      index = find_attr(svr_attr_def, plist->al_name, SRV_ATR_LAST);
+      if ((index = find_attr(svr_attr_def, plist->al_name, SRV_ATR_LAST)) < 0)
+        {
+        plist = (svrattrl *)GET_NEXT(plist->al_link);
+        continue;
+        }
 
       clear_attr(&temp, &svr_attr_def[index]);
       svr_attr_def[index].at_decode(&temp, plist->al_name, plist->al_resc, plist->al_value, 0);
@@ -1310,6 +1313,8 @@ void mgr_server_set(
       reply_badattr(PBSE_BADHOST, bad_attr, plist, preq);
       }
 
+    free(bad_host);
+
     return;
     } /* END if (rc == PBSE_BADACLHOST) */
   else if (rc != 0)
@@ -1632,7 +1637,7 @@ void mgr_node_set(
 
   struct pbsnode   *pnode = NULL;
   struct pbsnode  **problem_nodes = NULL;
-  struct prop props;
+  struct prop       props;
 
   if ((*preq->rq_ind.rq_manager.rq_objname == '\0') ||
       (*preq->rq_ind.rq_manager.rq_objname == '@') ||
@@ -1958,8 +1963,6 @@ static void mgr_node_delete(
     {
     /* handle single nodes */
     snprintf(log_buf,sizeof(log_buf),"%s",pnode->nd_name);
-    
-    nodename = strdup(pnode->nd_name);
 
     effective_node_delete(pnode);
 
