@@ -110,7 +110,7 @@ extern char *msg_manager;
 extern char *msg_movejob;
 extern char *pbs_o_host;
 
-int   svr_movejob(job *, char *, int *, struct batch_request *, int);
+int   svr_movejob(job *, char *, int *, struct batch_request *);
 int   svr_chkque(job *, pbs_queue *, char *, int, char *);
 job  *chk_job_request(char *, struct batch_request *);
 
@@ -134,7 +134,12 @@ int req_movejob(
     {
     return(PBSE_NONE);
     }
-
+  if (LOGLEVEL >= 7)
+    {
+    sprintf(log_buf, "%s", jobp->ji_qs.ji_jobid);
+    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
+  
   if ((jobp->ji_qs.ji_state != JOB_STATE_QUEUED) &&
       (jobp->ji_qs.ji_state != JOB_STATE_HELD) &&
       (jobp->ji_qs.ji_state != JOB_STATE_WAITING))
@@ -160,9 +165,9 @@ int req_movejob(
   /* We have found that sometimes the destination queue and the 
      parent queue are the same. If so we do not need to do
      anything else */
-  if (strcmp(jobp->ji_qhdr->qu_qs.qu_name, req->rq_ind.rq_move.rq_destin) == 0)
+  if (strcmp(jobp->ji_qs.ji_queue, req->rq_ind.rq_move.rq_destin) == 0)
     {
-    sprintf(log_buf, "Job %s already in queue %s", jobp->ji_qs.ji_jobid, jobp->ji_qhdr->qu_qs.qu_name);
+    sprintf(log_buf, "Job %s already in queue %s", jobp->ji_qs.ji_jobid, jobp->ji_qs.ji_queue);
     if (LOGLEVEL >= 7)
       {
       log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
@@ -172,7 +177,7 @@ int req_movejob(
     return(PBSE_NONE);
     }
 
-  switch (svr_movejob(jobp, req->rq_ind.rq_move.rq_destin, &local_errno, req, FALSE))
+  switch (svr_movejob(jobp, req->rq_ind.rq_move.rq_destin, &local_errno, req))
     {
 
     case 0:
@@ -237,8 +242,6 @@ int req_orderjob(
   char                  tmpqn[PBS_MAXQUEUENAME+1];
   struct batch_request *req = (struct batch_request *)vp;
   char                  log_buf[LOCAL_LOG_BUF_SIZE];
-  char                  job_id1[PBS_MAXSVRJOBID+1];
-  char                  job_id2[PBS_MAXSVRJOBID+1];
   pbs_queue            *pque1;
   pbs_queue            *pque2;
 
@@ -278,7 +281,8 @@ int req_orderjob(
     }
   else if ((pjob1->ji_qhdr == NULL) || (pjob2->ji_qhdr == NULL))
     {
-    req_reject(PBSE_BADSTATE, 0, req, NULL, "One of the jobs does not have a queue");     
+    req_reject(PBSE_BADSTATE, 0, req, NULL, "One of the jobs does not have a queue");
+    return(PBSE_NONE);
     }
   else if (pjob1->ji_qhdr != pjob2->ji_qhdr)
     {
@@ -286,7 +290,7 @@ int req_orderjob(
     int ok = FALSE;
 
     if ((pque2 = get_jobs_queue(&pjob2)) == NULL)
-      req_reject(PBSE_BADSTATE, 0, req, NULL, "job2 queue is unavailable");
+      rc = PBSE_BADSTATE;
     else
       {
       if ((rc = svr_chkque(pjob1, pque2, get_variable(pjob1, pbs_o_host), MOVE_TYPE_Order, NULL)) == PBSE_NONE)
@@ -294,7 +298,7 @@ int req_orderjob(
         unlock_queue(pque2, "req_orderjob", "pque2 svr_chkque pass", LOGLEVEL);
         if ((pque1 = get_jobs_queue(&pjob1)) == NULL)
           {
-          req_reject(PBSE_BADSTATE, 0, req, NULL, "job1 queue is unavailable");
+          rc = PBSE_BADSTATE;
           }
         else if (pjob1 != NULL)
           {
@@ -336,13 +340,9 @@ int req_orderjob(
     strcpy(tmpqn, pjob1->ji_qs.ji_queue);
     strcpy(pjob1->ji_qs.ji_queue, pjob2->ji_qs.ji_queue);
     strcpy(pjob2->ji_qs.ji_queue, tmpqn);
-    strcpy(job_id1, pjob1->ji_qs.ji_jobid);
-    strcpy(job_id2, pjob2->ji_qs.ji_jobid);
-    unlock_ji_mutex(pjob1, __func__, "5", LOGLEVEL);
-    unlock_ji_mutex(pjob2, __func__, "6", LOGLEVEL);
 
-    svr_dequejob(job_id1, FALSE);
-    svr_dequejob(job_id2, FALSE);
+    svr_dequejob(pjob1, FALSE);
+    svr_dequejob(pjob2, FALSE);
 
     if (svr_enquejob(pjob1, FALSE, -1) == PBSE_JOB_RECYCLED)
       pjob1 = NULL;
