@@ -129,6 +129,7 @@
 #include "ji_mutex.h"
 #include "user_info.h"
 #include "work_task.h"
+#include "req_runjob.h"
 
 
 /* External Functions Called: */
@@ -1372,11 +1373,16 @@ int req_quejob(
 
     hostname = index(oldid, '.');
 
-    *(hostname++) = '\0';
-
-    snprintf(pj->ji_qs.ji_jobid, PBS_MAXSVRJOBID, "%s[].%s",
-      oldid,
-      hostname);
+    if (hostname != NULL)
+      {
+      *(hostname++) = '\0';
+      
+      snprintf(pj->ji_qs.ji_jobid, PBS_MAXSVRJOBID, "%s[].%s",
+        oldid,
+        hostname);
+      }
+    else
+      snprintf(pj->ji_qs.ji_jobid, sizeof(pj->ji_qs.ji_jobid), "%s[]", oldid);
 
     free(oldid);    
     }
@@ -1423,6 +1429,8 @@ int req_quejob(
     svr_job_purge(pj);
     return rc;
     }
+  
+  job_save(pj, SAVEJOB_NEW, 0);
 
   /* link job into server's new jobs list request  */
   insert_job(&newjobs,pj);
@@ -1843,7 +1851,7 @@ int req_rdytocommit(
     unlink(namebuf);
     }
 
-  if (job_save(pj, SAVEJOB_NEW, 0) == -1)
+  if (job_save(pj, SAVEJOB_FULL, 0) == -1)
     {
     rc = PBSE_CAN_NOT_WRITE_FILE;
     snprintf(log_buf, LOCAL_LOG_BUF_SIZE,
@@ -1895,7 +1903,7 @@ int req_rdytocommit(
     log_record(
       PBSEVENT_JOB,
       PBS_EVENTCLASS_JOB,
-      (jobid != NULL) ? jobid : "NULL",
+      jobid,
       "ready to commit job completed");
     }
 
@@ -1983,7 +1991,7 @@ int req_commit(
 
 #ifdef AUTORUN_JOBS
 
-  struct batch_request *preq_run = '\0';
+  struct batch_request *preq_run = NULL;
   pbs_attribute        *pattr;
   int                   nodes_avail = -1;
   int                   dummy;
@@ -2174,6 +2182,10 @@ int req_commit(
 
   if ((pque = get_jobs_queue(&pj)) != NULL)
     {
+    /* None of the queue information we are accessing in 
+       this segment is volatile. Unlock the queue so we
+       don't deadlock in job_route */
+    unlock_queue(pque, __func__, log_buf, LOGLEVEL);
     if ((preq->rq_fromsvr == 0) &&
         (pque->qu_qs.qu_type == QTYPE_RoutePush) &&
         (pque->qu_attr[QA_ATR_Started].at_val.at_long != 0))
@@ -2182,7 +2194,6 @@ int req_commit(
         {
         snprintf(log_buf, LOCAL_LOG_BUF_SIZE, "can not route job %s",
             pj->ji_qs.ji_jobid);
-        unlock_queue(pque, __func__, log_buf, LOGLEVEL);
 
         if (LOGLEVEL >= 6)
           {
@@ -2203,7 +2214,6 @@ int req_commit(
       pj->ji_wattr[JOB_ATR_jobname].at_val.at_str,
       pque->qu_qs.qu_name);
 
-    unlock_queue(pque, __func__, "route success", LOGLEVEL);
     }
 
 #ifdef AUTORUN_JOBS
@@ -2220,16 +2230,16 @@ int req_commit(
   if ((pattr->at_val.at_long == 0) && (nodes_avail > 0))
     {
     /* Create a new batch request and fill it in */
-    preq_run = alloc_br(PBS_BATCH_AsyrunJob);
+    preq_run = alloc_br(PBS_BATCH_RunJob);
     preq_run->rq_perm = preq->rq_perm | ATR_DFLAG_OPWR;
     preq_run->rq_ind.rq_run.rq_resch = 0;
     preq_run->rq_ind.rq_run.rq_destin = rq_destin;
     preq_run->rq_fromsvr = preq->rq_fromsvr;
     preq_run->rq_extsz = preq->rq_extsz;
     preq_run->rq_noreply = TRUE; /* set for no replies */
-    memcpy(preq_run->rq_user, preq->rq_user, PBS_MAXUSER + 1);
-    memcpy(preq_run->rq_host, preq->rq_host, PBS_MAXHOSTNAME + 1);
-    memcpy(preq_run->rq_ind.rq_run.rq_jid, preq->rq_ind.rq_rdytocommit,PBS_MAXSVRJOBID + 1);
+    strcpy(preq_run->rq_user, preq->rq_user);
+    strcpy(preq_run->rq_host, preq->rq_host);
+    strcpy(preq_run->rq_ind.rq_run.rq_jid, preq->rq_ind.rq_rdytocommit);
     }
 
 #endif
@@ -2241,10 +2251,13 @@ int req_commit(
   /* if job array, setup the cloning work task */
   if (pj->ji_is_array_template)
     {
+    sprintf(log_buf, "threading job_clone_wt: job id %s", pj->ji_qs.ji_jobid);
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
     enqueue_threadpool_request(job_clone_wt, strdup(pj->ji_qs.ji_jobid));
     }
     
-  log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,pj->ji_qs.ji_jobid,log_buf);
+  sprintf(log_buf, "job_id: %s", pj->ji_qs.ji_jobid);
+  log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,__func__,log_buf);
 
   if ((pj->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
     {
