@@ -103,6 +103,8 @@
 #include "array.h"
 #include "svr_func.h" /* get_svr_attr_* */
 #include "ji_mutex.h"
+#include "req_register.h"
+#include "pbs_job.h"
 
 #define SYNC_SCHED_HINT_NULL 0
 #define SYNC_SCHED_HINT_FIRST 1
@@ -118,10 +120,9 @@
 extern int issue_to_svr(char *svr, struct batch_request *, void (*func)(struct work_task *));
 extern long calc_job_cost(job *);
 
-
 /* Local Private Functions */
 
-void set_depend_hold(job *, pbs_attribute *);
+void set_depend_hold(char *, pbs_attribute *);
 static int register_sync(struct depend *,  char *child, char *host, long);
 static int register_dep(pbs_attribute *, struct batch_request *, int, int *);
 static int unregister_dep(pbs_attribute *, struct batch_request *);
@@ -139,7 +140,7 @@ static int    build_depend(pbs_attribute *, char *);
 static void   clear_depend(struct depend *, int type, int exists);
 static void   del_depend(struct depend *);
 static void   release_cheapest(job *, struct depend *);
-static int    send_depend_req(job *, struct depend_job *pparent, int, int, int, void (*postfunc)(struct work_task *));
+int           send_depend_req(job *, struct depend_job *pparent, int, int, int, void (*postfunc)(batch_request *));
 
 /* External Global Data Items */
 
@@ -175,16 +176,17 @@ int req_register(
 
   {
   int                   made;
-  pbs_attribute        *pattr;
+  pbs_attribute        *pattr = NULL;
 
-  struct depend        *pdep;
+  struct depend        *pdep = NULL;
 
-  struct depend_job    *pdj;
+  struct depend_job    *pdj = NULL;
   job                  *pjob;
   char                 *ps;
   int                   rc = PBSE_NONE;
   int                   revtype;
   int                   type;
+  char                  job_id[PBS_MAXSVRJOBID + 1];
   char                  log_buf[LOCAL_LOG_BUF_SIZE + 1];
 
   /*  make sure request is from a server */
@@ -196,6 +198,12 @@ int req_register(
     return(PBSE_IVALREQ);
     }
 
+  if (LOGLEVEL >= 10)
+    {
+    snprintf(log_buf, sizeof(log_buf), "rq_parent: %s", preq->rq_ind.rq_register.rq_parent);
+    log_event(PBSEVENT_DEBUG, PBS_EVENTCLASS_QUEUE, __func__, log_buf);
+    }
+
   /* find the "parent" job specified in the request */
 
   if ((pjob = svr_find_job(preq->rq_ind.rq_register.rq_parent, TRUE)) == NULL)
@@ -393,7 +401,7 @@ int req_register(
                 {
                 /* has prior register, update it */
 
-                if (server_name != NULL)
+                if (server_name[0] != '\0')
                   snprintf(pdj->dc_svr, sizeof(pdj->dc_svr), "%s", server_name);
                 else
                   snprintf(pdj->dc_svr, sizeof(pdj->dc_svr), "%s", preq->rq_ind.rq_register.rq_svr);
@@ -460,7 +468,12 @@ int req_register(
 
                 del_depend(pdep);
 
-                set_depend_hold(pjob, pattr);
+                snprintf(job_id, sizeof(job_id), "%s", pjob->ji_qs.ji_jobid);
+                unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+                set_depend_hold(job_id, pattr);
+                pjob = svr_find_job(job_id, TRUE);
+                if (pjob == NULL)
+                  rc = PBSE_JOBNOTFOUND;
                 }
 
               break;
@@ -483,7 +496,12 @@ int req_register(
             char tmpcoststr[64];
             pdep->dp_released = 1;
 
-            set_depend_hold(pjob, pattr);
+            snprintf(job_id, sizeof(job_id), "%s", pjob->ji_qs.ji_jobid);
+            unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
+            set_depend_hold(job_id, pattr);
+            pjob = svr_find_job(job_id, TRUE);
+            if (pjob == NULL)
+              rc = PBSE_JOBNOTFOUND;
 
             sprintf(tmpcoststr, "%ld", preq->rq_ind.rq_register.rq_cost);
             pjob->ji_wattr[JOB_ATR_sched_hint].at_val.at_str =
@@ -568,7 +586,12 @@ int req_register(
         unregister_dep(pattr, preq);
         }
 
-      set_depend_hold(pjob, pattr);
+      snprintf(job_id, sizeof(job_id), "%s", pjob->ji_qs.ji_jobid);
+      unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
+      set_depend_hold(job_id, pattr);
+      pjob = svr_find_job(job_id, TRUE);
+      if (pjob == NULL)
+        rc = PBSE_JOBNOTFOUND;
 
       break;
 
@@ -625,7 +648,6 @@ int req_registerarray(
   struct batch_request *preq)  /* I */
 
   {
-  char        log_buf[LOCAL_LOG_BUF_SIZE + 1];
   job_array  *pa;
   char        array_name[PBS_MAXSVRJOBID + 1];
   char        range[MAXPATHLEN];
@@ -725,13 +747,7 @@ int req_registerarray(
 
   if (type < JOB_DEPEND_TYPE_AFTERSTARTARRAY)
     {
-    pthread_mutex_unlock(pa->ai_mutex);
-    if (LOGLEVEL >= 7)
-      {
-      sprintf(log_buf, "%s: unlocked ai_mutex", __func__);
-      log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
-      }
-
+    unlock_ai_mutex(pa, __func__, "1", LOGLEVEL);
     rc = PBSE_IVALREQ;
     req_reject(rc,0,preq,NULL,
       "Arrays may only be given array dependencies");
@@ -765,12 +781,7 @@ int req_registerarray(
       break;
     } /* END switch (preq->rq_ind.rq_register.rq_op */
 
-  pthread_mutex_unlock(pa->ai_mutex);
-  if (LOGLEVEL >= 7)
-    {
-    sprintf(log_buf, "%s: unlocked ai_mutex", __func__);
-    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
-    }
+  unlock_ai_mutex(pa, __func__, "2", LOGLEVEL);
 
   return(rc);
   } /* END req_registerarray() */
@@ -841,10 +852,10 @@ int register_array_depend(
     CLEAR_LINK(pdj->dc_link);
 
     snprintf(pdj->dc_child,sizeof(pdj->dc_child),"%s",preq->rq_ind.rq_register.rq_child);
-    if (server_name != NULL)
-      snprintf(pdj->dc_svr,sizeof(pdj->dc_svr),"%s",server_name);
+    if (server_name[0] != '\0')
+      snprintf(pdj->dc_svr, sizeof(pdj->dc_svr), "%s", server_name);
     else
-      snprintf(pdj->dc_svr,sizeof(pdj->dc_svr),"%s",preq->rq_ind.rq_register.rq_svr);
+      snprintf(pdj->dc_svr, sizeof(pdj->dc_svr), "%s", preq->rq_ind.rq_register.rq_svr);
 
     if (num_jobs == -1)
       {
@@ -877,6 +888,7 @@ void set_array_depend_holds(
   job_array *pa)
 
   {
+  char job_id[PBS_MAXSVRJOBID + 1];
   int  compareNumber;
 
   job *pjob;
@@ -974,7 +986,9 @@ void set_array_depend_holds(
           /* release the array's hold - set_depend_hold
            * will clear holds if there are no other dependencies
            * logged in set_depend_hold */
-          set_depend_hold(pjob,&pjob->ji_wattr[JOB_ATR_depend]);
+          snprintf(job_id, sizeof(job_id), "%s",  pjob->ji_qs.ji_jobid);
+          unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+          set_depend_hold(job_id,&pjob->ji_wattr[JOB_ATR_depend]);
           }
 
         unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
@@ -994,12 +1008,11 @@ void set_array_depend_holds(
  * i.e. the sending of register operations.
  */
 
-static void post_doq(
+void post_doq(
 
-  struct work_task *pwt)
+  batch_request *preq)
 
   {
-  struct batch_request *preq = get_remove_batch_request(pwt->wt_parm1);
   char                  log_buf[LOCAL_LOG_BUF_SIZE];
   char                 *msg;
   job                  *pjob;
@@ -1009,9 +1022,6 @@ static void post_doq(
   struct depend_job    *pdjb;
   char                 *jobid;
 
-  free(pwt->wt_mutex);
-  free(pwt);
-
   if (preq == NULL)
     return;
 
@@ -1055,9 +1065,9 @@ static void post_doq(
           pjob->ji_modified = 1;
           }
 
-        set_depend_hold(pjob, pattr);
-
         unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
+        set_depend_hold(jobid, pattr);
+
         }
       }
     }
@@ -1114,13 +1124,7 @@ static void alter_unreg(
           if ((pjob = svr_find_job(job_id, TRUE)) == NULL)
               return;
 
-          send_depend_req(
-            pjob,
-            oldjd,
-            type,
-            JOB_DEPEND_OP_UNREG,
-            SYNC_SCHED_HINT_NULL,
-            release_req);
+          send_depend_req(pjob, oldjd, type, JOB_DEPEND_OP_UNREG, SYNC_SCHED_HINT_NULL, free_br);
           pjob = NULL;
           }
 
@@ -1158,10 +1162,13 @@ int depend_on_que(
   int                type;
   job               *pjob = (job *)pj;
   pbs_queue         *pque = get_jobs_queue(&pjob);
-  char job_id[PBS_MAXSVRJOBID+1];
+  char               job_id[PBS_MAXSVRJOBID+1];
 
   strcpy(job_id, pjob->ji_qs.ji_jobid);
 
+  if (LOGLEVEL >= 10)
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, job_id);
+
   if (pque == NULL)
     {
     if (pjob == NULL)
@@ -1192,8 +1199,10 @@ int depend_on_que(
     }
 
   /* First set a System hold if required */
-
-  set_depend_hold(pjob, pattr);
+  unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
+  set_depend_hold(job_id, pattr);
+  if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
+    return PBSE_JOBNOTFOUND;
 
   /* Check if there are dependencies that require registering */
 
@@ -1249,12 +1258,11 @@ int depend_on_que(
  * post_doe - Post (reply) processing of requests processing for depend_on_exec
  */
 
-static void post_doe(
+void post_doe(
 
-  struct work_task *pwt)
+  batch_request *preq)
 
   {
-  struct batch_request *preq = get_remove_batch_request(pwt->wt_parm1);
   pbs_attribute        *pattr;
 
   struct depend        *pdep;
@@ -1263,9 +1271,6 @@ static void post_doe(
   job                  *pjob;
   char                 *jobid;
  
-  free(pwt->wt_mutex);
-  free(pwt);
-
   if (preq == NULL)
     return;
 
@@ -1357,13 +1362,7 @@ int depend_on_exec(
 
     if (pdj != NULL)
       {
-      send_depend_req(
-        pjob,
-        pdj,
-        pdep->dp_type,
-        JOB_DEPEND_OP_READY,
-        SYNC_SCHED_HINT_NULL,
-        release_req);
+      send_depend_req(pjob, pdj, pdep->dp_type, JOB_DEPEND_OP_READY, SYNC_SCHED_HINT_NULL, free_br);
       if ((pjob == NULL) &&
           ((pjob = svr_find_job(jobid, TRUE)) == NULL))
         return PBSE_JOBNOTFOUND;
@@ -1408,10 +1407,10 @@ int depend_on_exec(
 
 int depend_on_term(
 
-  job *pjob)
+  char *job_id)
 
   {
-  int                exitstat = pjob->ji_qs.ji_un.ji_exect.ji_exitstat;
+  int                exitstat;
   int                op;
   pbs_attribute     *pattr;
 
@@ -1421,16 +1420,20 @@ int depend_on_term(
   int                rc;
   int                shouldkill = 0;
   int                type;
-  char               job_id[PBS_MAXSVRJOBID+1];
   int                job_unlocked = 0;
+  job                *pjob;
  
-  strcpy(job_id, pjob->ji_qs.ji_jobid);
+  pjob = svr_find_job(job_id, FALSE);
+  if (pjob == NULL)
+    return(PBSE_JOBNOTFOUND);
 
+  exitstat = pjob->ji_qs.ji_un.ji_exect.ji_exitstat;
   pattr = &pjob->ji_wattr[JOB_ATR_depend];
 
   pdep = (struct depend *)GET_NEXT(pattr->at_val.at_list);
 
-  while (pdep != NULL)
+  while ((pdep != NULL) &&
+         (pjob != NULL))
     {
     op = -1;
 
@@ -1498,14 +1501,14 @@ int depend_on_term(
 
           while (pparent)
             {
-            if ((pjob == NULL) && 
-                ((pjob = svr_find_job(job_id, TRUE)) == NULL))
-              return(PBSE_JOBNOTFOUND);
+            if (job_unlocked == 1)
+              {
+              pjob = svr_find_job(job_id, TRUE);
+              if (pjob == NULL)
+                return(PBSE_JOBNOTFOUND);
+              }
 
-            rc = send_depend_req(pjob, pparent, type,
-                            JOB_DEPEND_OP_DELETE,
-                            SYNC_SCHED_HINT_NULL,
-                            release_req);
+            rc = send_depend_req(pjob, pparent, type, JOB_DEPEND_OP_DELETE, SYNC_SCHED_HINT_NULL, free_br);
 
             pjob = NULL;
             job_unlocked = 1;
@@ -1518,22 +1521,26 @@ int depend_on_term(
 
       } /* END switch(type) */
 
+
     if (op != -1)
       {
       pparent = (struct depend_job *)GET_NEXT(pdep->dp_jobs);
 
       while (pparent)
         {
-        if ((pjob == NULL) && 
-            ((pjob = svr_find_job(job_id, TRUE)) == NULL))
-          return(PBSE_JOBNOTFOUND);
+        if (job_unlocked == 1)
+          {
+          pjob = svr_find_job(job_id, TRUE);
+          if (pjob == NULL)
+            return(PBSE_JOBNOTFOUND);
+          }
 
         /* "release" the job to execute */
-        if ((rc = send_depend_req(pjob, pparent, type, op, SYNC_SCHED_HINT_NULL,
-                release_req)) != PBSE_NONE)
+        if ((rc = send_depend_req(pjob, pparent, type, op, SYNC_SCHED_HINT_NULL, free_br)) != PBSE_NONE)
           {
           return (rc);
           }
+
         job_unlocked = 1;
 
         pparent = (struct depend_job *)GET_NEXT(pparent->dc_link);
@@ -1541,7 +1548,8 @@ int depend_on_term(
       }
 
     pdep = (struct depend *)GET_NEXT(pdep->dp_link);
-    }
+    } /* END loop over each dependency */
+
   if (!job_unlocked)
     unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
 
@@ -1598,13 +1606,8 @@ static void release_cheapest(
     if (nreleased == 0)
       hint = SYNC_SCHED_HINT_FIRST;
 
-    if (send_depend_req(
-          pjob,
-          cheapest,
-          JOB_DEPEND_TYPE_SYNCWITH,
-          JOB_DEPEND_OP_RELEASE,
-          hint,
-          release_req) == 0)
+    if (send_depend_req(pjob, cheapest, JOB_DEPEND_TYPE_SYNCWITH,
+          JOB_DEPEND_OP_RELEASE, hint, free_br) == PBSE_NONE)
       {
       cheapest->dc_state = JOB_DEPEND_OP_RELEASE;
       }
@@ -1627,13 +1630,14 @@ static void release_cheapest(
 
 void set_depend_hold(
 
-  job           *pjob,
+  char          *job_id,
   pbs_attribute *pattr)
 
   {
   int  loop = 1;
   int  newstate;
   int  newsubst;
+  job  *pjob;
 
   struct depend *pdp = NULL;
 
@@ -1642,6 +1646,13 @@ void set_depend_hold(
   struct job *djp = NULL;
   int  substate = -1;
 
+  if (LOGLEVEL >= 10)
+    log_event(PBSEVENT_DEBUG, PBS_EVENTCLASS_JOB, __func__, job_id);
+
+  pjob = svr_find_job(job_id, TRUE);
+  if (pjob == NULL)
+    return;
+
   if (pattr->at_flags & ATR_VFLAG_SET)
     pdp = (struct depend *)GET_NEXT(pattr->at_val.at_list);
 
@@ -1679,7 +1690,14 @@ void set_depend_hold(
 
         if (djob)
           {
-          djp = svr_find_job(djob->dc_child, TRUE);
+          int jobids_match = 0;
+
+          /* if dc_child is the same job id as pjob don't
+             lock the job. It is already locked */
+          if (strcmp(djob->dc_child, pjob->ji_qs.ji_jobid))
+            djp = svr_find_job(djob->dc_child, TRUE);
+          else
+            jobids_match = 1;
 
           if (!djp ||
               ((pdp->dp_type == JOB_DEPEND_TYPE_AFTERSTART) &&
@@ -1700,8 +1718,10 @@ void set_depend_hold(
             substate = JOB_SUBSTATE_DEPNHOLD;
             }
 
-          if (djp != NULL)
+          if ((djp != NULL) && (jobids_match == 0))
             unlock_ji_mutex(djp, __func__, "1", LOGLEVEL);
+          else
+            jobids_match = 0;
           }
 
         break;
@@ -1717,6 +1737,7 @@ void set_depend_hold(
     pdp = (struct depend *)GET_NEXT(pdp->dp_link);
     }  /* END while ((pdp != NULL) && (loop != 0)) */
 
+
   if (substate == -1)
     {
     /* No (more) dependencies, clear system hold and set state */
@@ -1761,6 +1782,8 @@ void set_depend_hold(
     svr_setjobstate(pjob, JOB_STATE_HELD, substate, FALSE);
     }
 
+  unlock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
+
   return;
   }  /* END set_depend_hold() */
 
@@ -1816,6 +1839,13 @@ static struct depend *find_depend(
   {
 
   struct depend *pdep = NULL;
+  char           log_buf[LOCAL_LOG_BUF_SIZE];
+
+  if (LOGLEVEL >= 10)
+    {
+    snprintf(log_buf, sizeof(log_buf), "type: %d", type);
+    log_event(PBSEVENT_DEBUG, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
 
   if (pattr->at_flags & ATR_VFLAG_SET)
     {
@@ -1885,7 +1915,7 @@ static int register_sync(
     {
     /* existing regist., just update the location of the child */
 
-    if (server_name != NULL)
+    if (server_name[0] != '\0')
       strcpy(pdj->dc_svr, server_name);
     else
       strcpy(pdj->dc_svr, host);
@@ -1951,7 +1981,7 @@ static int register_dep(
 
   if ((pdj = find_dependjob(pdep, preq->rq_ind.rq_register.rq_child)))
     {
-    if (server_name != NULL)
+    if (server_name[0] != '\0')
       strcpy(pdj->dc_svr, server_name);
     else
       strcpy(pdj->dc_svr, preq->rq_ind.rq_register.rq_svr);
@@ -2056,24 +2086,32 @@ static int unregister_sync(
   return(0);
   }  /* END unregister_sync() */
 
+
+
+
 /*
  * find_dependjob - find a child dependent job with a certain job id
  */
 
-static struct depend_job *find_dependjob(
+struct depend_job *find_dependjob(
 
-        struct depend *pdep,
-        char          *name)
+  struct depend *pdep,
+  char          *name)
 
   {
-
   struct depend_job *pdj;
+  long               display_server_suffix = TRUE;
+
+  get_svr_attr_l(SRV_ATR_display_job_server_suffix, &display_server_suffix);
 
   pdj = (struct depend_job *)GET_NEXT(pdep->dp_jobs);
 
   while (pdj)
     {
-    if (!strcmp(name, pdj->dc_child))
+    if ((!strcmp(name, pdj->dc_child)) ||
+        ((display_server_suffix == FALSE) &&
+         (!strncmp(name, pdj->dc_child, strlen(name))) &&
+         (strchr(name, '.') == NULL)))
       break;
 
     pdj = (struct depend_job *)GET_NEXT(pdj->dc_link);
@@ -2085,16 +2123,15 @@ static struct depend_job *find_dependjob(
 
 
 
-
 /*
  * make_dependjob - add a depend_job structue
  */
 
 static struct depend_job *make_dependjob(
 
-        struct depend *pdep,
-        char          *jobid,
-        char          *host)
+  struct depend *pdep,
+  char          *jobid,
+  char          *host)
 
   {
 
@@ -2110,7 +2147,7 @@ static struct depend_job *make_dependjob(
     pdj->dc_cost  = 0;
 
     strcpy(pdj->dc_child, jobid);
-    if (server_name != NULL)
+    if (server_name[0] != '\0')
       strcpy(pdj->dc_svr, server_name);
     else
       strcpy(pdj->dc_svr, host);
@@ -2129,19 +2166,18 @@ static struct depend_job *make_dependjob(
  * send_depend_req - build and send a Register Dependent request
  */
 
-static int send_depend_req(
+int send_depend_req(
 
   job                *pjob,
   struct depend_job  *pparent,
   int                 type,
   int                 op,
   int                 schedhint,
-  void               (*postfunc)(struct work_task *))
+  void               (*postfunc)(batch_request *))
 
   {
   int                   rc = 0;
   int                   i;
-  char                 *myid = "send_depend_req";
   char                  job_id[PBS_MAXSVRJOBID + 1];
   char                  br_id[MAXLINE];
 
@@ -2152,13 +2188,26 @@ static int send_depend_req(
 
   if (preq == NULL)
     {
-    log_err(errno, myid, msg_err_malloc);
+    log_err(errno, __func__, msg_err_malloc);
     unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
     return(PBSE_SYSTEM);
     }
 
+  if (LOGLEVEL >= 10)
+    {
+    snprintf(log_buf, sizeof(log_buf), "type: %d - job: %s - parent job: %s", 
+        type, pjob->ji_qs.ji_jobid, pparent->dc_child);
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
+
   for (i = 0;i < PBS_MAXUSER;++i)
     {
+    if (pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str == NULL)
+      {
+      unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
+      free_br(preq);
+      return(PBSE_BADATVAL);
+      }
     preq->rq_ind.rq_register.rq_owner[i] =
       pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str[i];
 
@@ -2210,8 +2259,13 @@ static int send_depend_req(
   get_batch_request_id(preq);
   strcpy(br_id, preq->rq_id);
 
-  if ((rc = issue_to_svr(pparent->dc_svr, preq, postfunc)) != PBSE_NONE)
+  if ((rc = issue_to_svr(pparent->dc_svr, preq, NULL)) != PBSE_NONE)
     {
+    if (strcmp(pparent->dc_svr, server_name))
+      {
+      free_br(preq);
+      }
+
     sprintf(log_buf, "Unable to perform dependency with job %s\n", pparent->dc_child);
 
     if ((preq = get_remove_batch_request(br_id)) != NULL)
@@ -2219,6 +2273,8 @@ static int send_depend_req(
 
     return(rc);
     }
+  else if (strcmp(pparent->dc_svr, server_name))
+    postfunc(preq);
 
   return(PBSE_NONE);
   }  /* END send_depend_req() */
@@ -2980,7 +3036,7 @@ static int build_depend(
 
           if (pwhere)
             {
-            if (server_name != NULL)
+            if (server_name[0] != '\0')
               strcpy(pdjb->dc_svr, server_name);
             else
               strcpy(pdjb->dc_svr, pwhere + 1);
