@@ -772,13 +772,15 @@ int svr_resc_size = 0;
 int init_resc_defs(void)
 
   {
-  resource_def *tmpresc = NULL;
-  int rindex = 0, dindex = 0, unkindex = 0;
+  int                   rindex = 0;
+  int                   dindex = 0;
+  int                   unkindex = 0;
 #ifndef PBS_MOM
 
+  resource_def         *tmpresc = NULL;
   struct array_strings *resc_arst = NULL;
   char                 *extra_resc;
-  int   resc_num = 0;
+  int                   resc_num = 0;
 #endif
 
   svr_resc_size = sizeof(svr_resc_def_const) / sizeof(resource_def);
@@ -832,8 +834,8 @@ int init_resc_defs(void)
 
   unkindex = rindex;
 
+#ifndef PBS_MOM
   /* copy our dynamic resources */
-
   if (tmpresc)
     {
     for (dindex = 0; (tmpresc + dindex)->rs_decode; dindex++)
@@ -847,22 +849,15 @@ int init_resc_defs(void)
 
     free(tmpresc);
     }
+#endif
 
   /* copy the last "unknown" resource */
   memcpy(svr_resc_def + rindex, svr_resc_def_const + unkindex, sizeof(resource_def));
 
   svr_resc_size = rindex + 1;
 
-  /* uncomment if you feel like debugging this
-    for (rindex=0; rindex<svr_resc_size; rindex++)
-      {
-      fprintf(stderr,"resource: %s (%d)\n",(svr_resc_def+rindex)->rs_name,rindex);
-      }
-  */
-  return 0;
-  }
-
-
+  return(PBSE_NONE);
+  } /* END init_resc_defs() */
 
 
 
@@ -1269,13 +1264,13 @@ int set_mppnodect(
   int            op)
 
   {
-  int width;
-  int nppn;
-  int nodect;
-  int have_mppwidth = 0;
-  int have_mppnppn = 0;
+  int           width;
+  int           nppn;
+  int           nodect;
+  int           have_mppwidth = 0;
+  int           have_mppnppn = 0;
   resource_def *pdef;
-  resource *pent = NULL;
+  resource     *pent = NULL;
 
   /* Go find the currently known width, nppn attributes */
 
@@ -1283,44 +1278,47 @@ int set_mppnodect(
   nppn = 0;
 
   if (((pdef = find_resc_def(svr_resc_def,"mppwidth",svr_resc_size))) &&
-    ((pent = find_resc_entry(attr,pdef))))
+      ((pent = find_resc_entry(attr,pdef))))
     {
     width = pent->rs_value.at_val.at_long;
     have_mppwidth = 1;
     }
 
   if (((pdef = find_resc_def(svr_resc_def,"mppnppn",svr_resc_size))) &&
-    ((pent = find_resc_entry(attr,pdef))))
+      ((pent = find_resc_entry(attr,pdef))))
     {
     nppn = pent->rs_value.at_val.at_long;
     have_mppnppn = 1;
-    }
-
-  /* Check for width less than a node */
-
-  if ((width) && (width < nppn))
-    {
-    nppn = width;
-    pent->rs_value.at_val.at_long = nppn;
-    pent->rs_value.at_flags |= ATR_VFLAG_SET;
+  
+    /* Check for width less than a node */
+    if ((width) && (width < nppn))
+      {
+      nppn = width;
+      pent->rs_value.at_val.at_long = nppn;
+      pent->rs_value.at_flags |= ATR_VFLAG_SET;
+      }
     }
 
   /* Compute an estimate for the number of nodes needed */
 
   nodect = width;
-  if (nppn>1)
+  if (nppn > 1)
     {
     nodect = (nodect + nppn - 1) / nppn;
     }
 
   /* Find or create the "mppnodect" pbs_attribute entry */
 
-  if (((pdef = find_resc_def(svr_resc_def,"mppnodect",svr_resc_size))) &&
-    (((pent = find_resc_entry(attr,pdef)) == NULL)) &&
-    (((pent = add_resource_entry(attr,pdef)) == 0)))
+  if ((pdef = find_resc_def(svr_resc_def,"mppnodect",svr_resc_size))) 
     {
-    return (PBSE_SYSTEM);
+    if (((pent = find_resc_entry(attr,pdef)) == NULL) &&
+        ((pent = add_resource_entry(attr,pdef)) == NULL))
+      {
+      return(PBSE_SYSTEM);
+      }
     }
+  else
+    return(PBSE_SYSTEM);
 
   /* Update the value */
 
@@ -1332,10 +1330,10 @@ int set_mppnodect(
     {
     pent->rs_value.at_val.at_long = nodect;
     }
+
   pent->rs_value.at_flags |= ATR_VFLAG_SET;
 
-  return (0);
-
+  return(PBSE_NONE);
   } /* END set_mppnodect() */
 
 
