@@ -139,6 +139,7 @@
 #include "../lib/Libutils/u_lock_ctl.h" /* *startup */
 #include "ji_mutex.h"
 #include "user_info.h"
+#include "svr_jobfunc.h"
 
 #define MSG_LEN_LONG 160
 
@@ -157,7 +158,6 @@ extern char  *msg_badwait;  /* error message */
 extern char  *msg_daemonname;
 extern char  *pbs_o_host;
 extern char   server_name[];
-extern all_queues svr_queues;
 extern int    comp_resc_lt;
 extern int    comp_resc_gt;
 extern int    svr_do_schedule;
@@ -284,6 +284,66 @@ const char *PJobSubState[] =
 
 
 
+
+int insert_into_alljobs_by_rank(
+
+  struct all_jobs *aj,
+  job             *pjob,
+  char            *jobid)
+
+  {
+  job  *pjcur;
+  int   iter = -1;
+  long  job_qrank = pjob->ji_wattr[JOB_ATR_qrank].at_val.at_long;
+  int   index = -1;
+  
+  unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
+
+  while ((pjcur = next_job_from_back(aj, &iter)) != NULL)
+    {
+    if (job_qrank > pjcur->ji_wattr[JOB_ATR_qrank].at_val.at_long)
+      {
+      break;
+      }
+    
+    if (strcmp(jobid, pjcur->ji_qs.ji_jobid) == 0)
+      {
+      unlock_ji_mutex(pjcur, __func__, "6", LOGLEVEL);
+      return(ALREADY_IN_LIST);
+      }
+
+    unlock_ji_mutex(pjcur, __func__, "7", LOGLEVEL);
+    }
+
+  if (pjcur != NULL)
+    {
+    index = get_jobs_index(aj, pjcur);
+    unlock_ji_mutex(pjcur, __func__, "8", LOGLEVEL);
+    pjcur = NULL;
+    }
+
+  if ((pjob = svr_find_job(jobid, FALSE)) == NULL)
+    {
+    return(PBSE_JOBNOTFOUND);
+    }
+  
+  if (index == -1)
+    {
+    /* link first in list */
+    insert_job_first(aj, pjob);
+    }
+  else
+    {
+    /* link after 'current' job in list */
+    insert_job_after_index(aj, index, pjob);
+    }
+
+  return(PBSE_NONE);
+  } /* END insert_into_alljobs_by_rank() */
+
+
+
+
 /*
  * svr_enquejob() - enqueue job into specified queue
  */
@@ -296,18 +356,19 @@ int svr_enquejob(
   {
   pbs_attribute *pattrjb;
   attribute_def *pdef;
-  job           *pjcur;
   pbs_queue     *pque;
   int            rc;
-  int            iter;
   char           log_buf[LOCAL_LOG_BUF_SIZE];
   time_t         time_now = time(NULL);
   char           job_id[PBS_MAXSVRJOBID+1];
   char           queue_name[PBS_MAXQUEUENAME+1];
-  long           job_qrank = -1;
+  int            total_jobs = 0;
+  int            user_jobs = 0;
+  int            array_jobs = 0;
 
   /* make sure queue is still there, there exists a small window ... */
   strcpy(job_id, pjob->ji_qs.ji_jobid);
+  /* ji_qs.ji_queue now holds the name of the destination queue */
   strcpy(queue_name, pjob->ji_qs.ji_queue);
   unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
   pque = find_queuebyname(queue_name);
@@ -323,11 +384,42 @@ int svr_enquejob(
 
   if (pjob->ji_being_recycled == TRUE)
     {
-    unlock_queue(pque, __func__, NULL, 0);
-    unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
+    unlock_queue(pque, __func__, NULL, LOGLEVEL);
+    unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
     return(PBSE_JOB_RECYCLED);
     }
 
+  /* Check again if there are any maximum queuable limits */
+  if (pjob->ji_is_array_template)
+    {
+    array_jobs = num_array_jobs(pjob->ji_wattr[JOB_ATR_job_array_request].at_val.at_str);
+    if (array_jobs > 0)
+      array_jobs--;
+    }
+      
+  if ((pque->qu_attr[QA_ATR_MaxJobs].at_flags & ATR_VFLAG_SET))
+    {
+    total_jobs = count_queued_jobs(pque, NULL);
+    if (total_jobs + array_jobs >= pque->qu_attr[QA_ATR_MaxJobs].at_val.at_long)
+      {
+      unlock_queue(pque, __func__, "1", LOGLEVEL);
+      unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
+      return(PBSE_MAXQUED);
+      }
+    }
+
+
+  if ((pque->qu_attr[QA_ATR_MaxUserJobs].at_flags & ATR_VFLAG_SET))
+    {
+    user_jobs = count_queued_jobs(pque, pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str);
+    if (user_jobs >= pque->qu_attr[QA_ATR_MaxUserJobs].at_val.at_long)
+      {
+      unlock_queue(pque, __func__, "1", LOGLEVEL);
+      unlock_ji_mutex(pjob, __func__, "3", LOGLEVEL);
+      return(PBSE_MAXUSERQUED);
+      }
+    }
+
   /* add job to server's 'all job' list and update server counts */
 
 #ifndef NDEBUG
@@ -356,14 +448,13 @@ int svr_enquejob(
       unlock_sv_qs_mutex(server.sv_qs_mutex, __func__);
 
     pthread_mutex_lock(server.sv_jobstates_mutex);
-
     server.sv_jobstates[pjob->ji_qs.ji_state]++;
-
     pthread_mutex_unlock(server.sv_jobstates_mutex);
     }
   
   /* place into array_summary if necessary */
-  if (pjob->ji_is_array_template || pjob->ji_arraystruct == NULL)
+  if ((pjob->ji_is_array_template) ||
+      (pjob->ji_arraystructid[0] == '\0'))
     {
     if ((rc = has_job(&array_summary, pjob)) == FALSE)
       {
@@ -379,47 +470,16 @@ int svr_enquejob(
     
   if (!pjob->ji_is_array_template)
     {
-    iter = -1;
+    rc = insert_into_alljobs_by_rank(pque->qu_jobs, pjob, job_id);
 
-    /* we have to unlock the job because next_job_from_back may 
-       give us this job */
-    job_qrank = pjob->ji_wattr[JOB_ATR_qrank].at_val.at_long;
-    unlock_ji_mutex(pjob, __func__, "4", LOGLEVEL);
-
-    while ((pjcur = next_job_from_back(pque->qu_jobs, &iter)) != NULL)
+    if ((rc == ALREADY_IN_LIST) ||
+        (rc == PBSE_JOBNOTFOUND))
       {
-      if (job_qrank > pjcur->ji_wattr[JOB_ATR_qrank].at_val.at_long)
-        {
-        unlock_ji_mutex(pjcur, __func__, "5", LOGLEVEL);
-        break;
-        }
+      unlock_queue(pque, __func__, "not array_template check", LOGLEVEL);
+      if (rc == ALREADY_IN_LIST)
+        rc = PBSE_NONE;
 
-      if (strcmp(job_id, pjcur->ji_qs.ji_jobid) == 0)
-        {
-        unlock_ji_mutex(pjcur, __func__, "6", LOGLEVEL);
-        unlock_queue(pque, __func__, "not array_template check", LOGLEVEL);
-        return(PBSE_NONE);
-        }
-
-      unlock_ji_mutex(pjcur, __func__, "7", LOGLEVEL);
-      }
-
-    if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
-      {
-      unlock_queue(pque, __func__, "array_template check lost job", LOGLEVEL);
-      return(PBSE_JOBNOTFOUND);
-      }
-
-    if (pjcur == NULL)
-      {
-      /* link first in list */
-      insert_job_first(pque->qu_jobs, pjob);
-      }
-    else
-      {
-      /* link after 'current' job in list */
-      insert_job_after(pque->qu_jobs, pjcur, pjob);
-      unlock_ji_mutex(pjcur, __func__, "8", LOGLEVEL);
+      return(rc);
       }
 
     /* update counts: queue and queue by state */
@@ -430,48 +490,19 @@ int svr_enquejob(
     increment_queued_jobs(pque->qu_uih, pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str, pjob);
     }
 
-  if (pjob->ji_is_array_template || pjob->ji_arraystruct == NULL)
+  if ((pjob->ji_is_array_template) ||
+      (pjob->ji_arraystructid[0] == '\0'))
     {
-    iter = -1;
+    rc = insert_into_alljobs_by_rank(pque->qu_jobs_array_sum, pjob, job_id);
 
-    job_qrank = pjob->ji_wattr[JOB_ATR_qrank].at_val.at_long;
-    unlock_ji_mutex(pjob, __func__, "9", LOGLEVEL);
-
-    while ((pjcur = next_job_from_back(pque->qu_jobs_array_sum,&iter)) != NULL)
+    if ((rc == ALREADY_IN_LIST) ||
+        (rc == PBSE_JOBNOTFOUND))
       {
-      if (job_qrank > pjcur->ji_wattr[JOB_ATR_qrank].at_val.at_long)
-        {
-        unlock_ji_mutex(pjcur, __func__, "10", LOGLEVEL);
-        break;
-        }
+      unlock_queue(pque, __func__, "not array_template check", LOGLEVEL);
+      if (rc == ALREADY_IN_LIST)
+        rc = PBSE_NONE;
 
-      if (strcmp(job_id, pjcur->ji_qs.ji_jobid) == 0)
-        {
-        unlock_ji_mutex(pjcur, __func__, "11", LOGLEVEL);
-        unlock_queue(pque, __func__, "not array_template check", LOGLEVEL);
-        return PBSE_NONE;
-        }
-
-      unlock_ji_mutex(pjcur, __func__, "12", LOGLEVEL);
-      } /* end of while */
-
-    if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
-      {
-      unlock_queue(pque, __func__, "array_template check lost job", LOGLEVEL);
-      return(PBSE_JOBNOTFOUND);
-      }
-
-    if (pjcur == NULL)
-      {
-      /* link first in list */
-      insert_job_first(pque->qu_jobs_array_sum,pjob);
-      }
-    else
-      {
-      /* link after 'current' job in list */
-      insert_job_after(pque->qu_jobs_array_sum,pjcur,pjob);
-
-      unlock_ji_mutex(pjcur, __func__, "13", LOGLEVEL);
+      return(rc);
       }
     }
 
@@ -538,8 +569,8 @@ int svr_enquejob(
     unlock_queue(pque, __func__, "anything", LOGLEVEL);
 
     if ((pjob->ji_qs.ji_state != JOB_STATE_COMPLETE) && 
-      (pjob->ji_qs.ji_substate != JOB_SUBSTATE_COMPLETE) && 
-      (pjob->ji_wattr[JOB_ATR_depend].at_flags & ATR_VFLAG_SET))
+        (pjob->ji_qs.ji_substate != JOB_SUBSTATE_COMPLETE) && 
+        (pjob->ji_wattr[JOB_ATR_depend].at_flags & ATR_VFLAG_SET))
       {
       if ((rc = depend_on_que(&
                               pjob->ji_wattr[JOB_ATR_depend],
@@ -551,7 +582,6 @@ int svr_enquejob(
       }
 
     /* set eligible time */
-
     if (((pjob->ji_wattr[JOB_ATR_etime].at_flags & ATR_VFLAG_SET) == 0) &&
         (pjob->ji_qs.ji_state == JOB_STATE_QUEUED))
       {
@@ -577,6 +607,8 @@ int svr_enquejob(
     
     unlock_queue(pque, __func__, "route job", LOGLEVEL);
     }
+  else
+    unlock_queue(pque, __func__, "pull queue", LOGLEVEL);
 
   return(PBSE_NONE);
   }  /* END svr_enquejob() */
@@ -592,26 +624,20 @@ int svr_enquejob(
 
 int svr_dequejob(
 
-  char *job_id,                  /* I, M */
-  int   parent_queue_mutex_held) /* I */
+  job *pjob,                  /* I, M */
+  int  parent_queue_mutex_held) /* I */
 
   {
   int            bad_ct = 0;
   int            rc = PBSE_NONE;
-  job           *pjob = NULL;
   pbs_attribute *pattr;
   pbs_queue     *pque;
   resource      *presc;
   char           log_buf[LOCAL_LOG_BUF_SIZE];
 
   /* remove job from server's all job list and reduce server counts */
-
-  if ((pjob = svr_find_job(job_id, FALSE)) == NULL)
-    return(PBSE_JOBNOTFOUND);
-
-
-  if (LOGLEVEL >= 10)
-    LOG_EVENT(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
+  if (LOGLEVEL >= 6)
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, pjob->ji_qs.ji_jobid);
 
   if (parent_queue_mutex_held == FALSE)
     {
@@ -670,8 +696,6 @@ int svr_dequejob(
     if (parent_queue_mutex_held == FALSE)
       unlock_queue(pque, __func__, NULL, LOGLEVEL);
     }
-  else if (pjob == NULL)
-    return(PBSE_JOBNOTFOUND);
 
 #ifndef NDEBUG
 
@@ -679,11 +703,14 @@ int svr_dequejob(
     pque ? pque->qu_qs.qu_name : "unknown queue",
     PJobState[pjob->ji_qs.ji_state]);
 
-  log_event(PBSEVENT_DEBUG2,PBS_EVENTCLASS_JOB,job_id,log_buf);
+  log_event(PBSEVENT_DEBUG2, PBS_EVENTCLASS_JOB, pjob->ji_qs.ji_jobid, log_buf);
 
   if (bad_ct)   /* state counts are all messed up */
     {
     char queue_name[PBS_MAXQUEUENAME];
+    char           job_id[PBS_MAXSVRJOBID+1];
+
+    strcpy(job_id, pjob->ji_qs.ji_jobid);
 
     /* this function will lock queues and jobs */
     unlock_ji_mutex(pjob, __func__, NULL, 0);
@@ -798,7 +825,7 @@ int svr_setjobstate(
     {
     sprintf(log_buf, "%s: setting job %s state from %s-%s to %s-%s (%d-%d)\n",
       __func__,
-      (pjob->ji_qs.ji_jobid != NULL) ? pjob->ji_qs.ji_jobid : "",
+      pjob->ji_qs.ji_jobid,
       PJobState[pjob->ji_qs.ji_state],
       PJobSubState[pjob->ji_qs.ji_substate],
       PJobState[newstate],
@@ -806,7 +833,7 @@ int svr_setjobstate(
       newstate,
       newsubstate);
 
-    log_event(PBSEVENT_ERROR, PBS_EVENTCLASS_SERVER, msg_daemonname, log_buf);
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
     }
 
   /*
@@ -1086,7 +1113,7 @@ int chk_svr_resc_limit(
   resource     *svrc;
   resource     *cmpwith;
 
-  int           LimitIsFromQueue;
+  int           LimitIsFromQueue = FALSE;
   char         *LimitName;
 
   /* NOTE:  support Cray-specific evaluation */
@@ -1206,7 +1233,8 @@ int chk_svr_resc_limit(
         }
 
       /* Added 6/14/2010 Ken Nielson for ability to parse the procs resource */
-      else if ((jbrc->rs_defin == procresc) && (qtype == QTYPE_Execution))
+      else if ((jbrc->rs_defin == procresc) &&
+               (qtype == QTYPE_Execution))
         {
         proc_ct = jbrc->rs_value.at_val.at_long;
         }
@@ -1336,7 +1364,7 @@ int chk_svr_resc_limit(
       mpp_nodect = (mpp_nodect + mpp_nppn - 1) / mpp_nppn;
       }
 
-    LimitIsFromQueue = 0;
+    LimitIsFromQueue = FALSE;
     LimitName = mppnodect_resource->rs_defin->rs_name;
     
     pthread_mutex_lock(server.sv_attr_mutex);
@@ -1613,6 +1641,7 @@ int svr_chkque(
   int failed_group_acl = 0;
   int failed_user_acl  = 0;
   int user_jobs;
+  int total_jobs;
 
   struct array_strings *pas;
   int j = 0;
@@ -1694,16 +1723,19 @@ int svr_chkque(
         if ((pjob->ji_wattr[JOB_ATR_interactive].at_flags & ATR_VFLAG_SET) &&
             (pjob->ji_wattr[JOB_ATR_interactive].at_val.at_long > 0))
           {
-          if (strcmp(Q_DT_interactive,
-                     pque->qu_attr[QA_ATR_DisallowedTypes].at_val.at_arst->as_string[i]) == 0)
+          if (pque->qu_attr[QA_ATR_DisallowedTypes].at_val.at_arst != NULL)
             {
-            if (EMsg) 
-              snprintf(EMsg, 1024,
-                "interactive job is not allowed for queue: user %s, queue %s",
-                pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str,
-                pque->qu_qs.qu_name);
+            if (strcmp(Q_DT_interactive,
+                       pque->qu_attr[QA_ATR_DisallowedTypes].at_val.at_arst->as_string[i]) == 0)
+              {
+              if (EMsg) 
+                snprintf(EMsg, 1024,
+                  "interactive job is not allowed for queue: user %s, queue %s",
+                  pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str,
+                  pque->qu_qs.qu_name);
 
-            return(PBSE_NOINTERACTIVE);
+              return(PBSE_NOINTERACTIVE);
+              }
             }
           }
         else /* else job is batch... */
@@ -1931,7 +1963,7 @@ int svr_chkque(
     if ((pque->qu_attr[QA_ATR_MaxJobs].at_flags & ATR_VFLAG_SET)) 
       {
       unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-      user_jobs = count_queued_jobs(pque, NULL);
+      total_jobs = count_queued_jobs(pque, NULL);
 
       lock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
       if (pjob->ji_being_recycled == TRUE)
@@ -1940,7 +1972,7 @@ int svr_chkque(
         return(PBSE_JOB_RECYCLED);
         }
 
-      if ((user_jobs + array_jobs) >= pque->qu_attr[QA_ATR_MaxJobs].at_val.at_long)
+      if ((total_jobs + array_jobs) >= pque->qu_attr[QA_ATR_MaxJobs].at_val.at_long)
         {
         if (EMsg)
           snprintf(EMsg, 1024,
@@ -1969,7 +2001,7 @@ int svr_chkque(
         return(PBSE_JOB_RECYCLED);
         }
 
-      if (user_jobs + array_jobs >= pque->qu_attr[QA_ATR_MaxUserJobs].at_val.at_long)
+      if ((user_jobs + array_jobs) >= pque->qu_attr[QA_ATR_MaxUserJobs].at_val.at_long)
         {
         if (EMsg)
           snprintf(EMsg, 1024,
@@ -2819,7 +2851,7 @@ int lock_ji_mutex(
   char *err_msg = NULL;
   char stub_msg[] = "no pos";
 
-  if (logging >= 20)
+  if (logging >= 10)
     {
     err_msg = (char *)calloc(1, MSG_LEN_LONG);
     if (msg == NULL)
@@ -2830,9 +2862,9 @@ int lock_ji_mutex(
 
   if (pthread_mutex_lock(pjob->ji_mutex) != 0)
     {
-    if (logging >= 20)
+    if (logging >= 10)
       {
-      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot lock queue %s mutex in method %s",
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot lock job %s mutex in method %s",
                                    pjob->ji_qs.ji_jobid, id);
       log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
       }
@@ -2858,7 +2890,7 @@ int unlock_ji_mutex(
   char *err_msg = NULL;
   char stub_msg[] = "no pos";
 
-  if (logging >= 20)
+  if (logging >= 10)
     {
     err_msg = (char *)calloc(1, MSG_LEN_LONG);
     if (msg == NULL)
@@ -2869,9 +2901,9 @@ int unlock_ji_mutex(
 
   if (pthread_mutex_unlock(pjob->ji_mutex) != 0)
     {
-    if (logging >= 20)
+    if (logging >= 10)
       {
-      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot unlock queue %s mutex in method %s",
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot unlock job %s mutex in method %s",
                                           pjob->ji_qs.ji_jobid, id);
       log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
       }
@@ -2885,4 +2917,156 @@ int unlock_ji_mutex(
    }
 
 
+int lock_ai_mutex(
+
+  job_array  *pa,
+  const char *id,
+  char       *msg,
+  int        logging)
+  {
+  int rc = PBSE_NONE;
+  char *err_msg = NULL;
+  char stub_msg[] = "no pos";
+
+  if (logging >= 10)
+    {
+    err_msg = (char *)calloc(1, MSG_LEN_LONG);
+    if (msg == NULL)
+      msg = stub_msg;
+    snprintf(err_msg, MSG_LEN_LONG, "locking %s in method %s-%s", pa->ai_qs.parent_id, id, msg);
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+    }
+
+  if (pthread_mutex_lock(pa->ai_mutex) != 0)
+    {
+    if (logging >= 10)
+      {
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot lock job array %s mutex in method %s",
+                                   pa->ai_qs.parent_id, id);
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+      }
+    rc = PBSE_MUTEX;
+    }
+
+  if (err_msg != NULL)
+  free(err_msg);
+
+  return rc;
+  }
+
+
+int unlock_ai_mutex(
+
+  job_array  *pa,
+  const char *id,
+  char       *msg,
+  int        logging)
+
+  {
+  int rc = PBSE_NONE;
+  char *err_msg = NULL;
+  char stub_msg[] = "no pos";
+
+  if (logging >= 10)
+    {
+    err_msg = (char *)calloc(1, MSG_LEN_LONG);
+    if (msg == NULL)
+      msg = stub_msg;
+    snprintf(err_msg, MSG_LEN_LONG, "unlocking %s in method %s-%s", pa->ai_qs.parent_id, id, msg);
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+    }
+
+  if (pthread_mutex_unlock(pa->ai_mutex) != 0)
+    {
+    if (logging >= 10)
+      {
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot unlock job array %s mutex in method %s",
+                                   pa->ai_qs.parent_id, id);
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+      }
+    rc = PBSE_MUTEX;
+    }
+
+  if (err_msg != NULL)
+  free(err_msg);
+
+  return rc;
+  }
+
+int lock_alljobs_mutex(
+
+  struct all_jobs *aj,
+  const char      *id,
+  char            *msg,
+  int             logging)
+
+  {
+  int rc = PBSE_NONE;
+  char *err_msg = NULL;
+  char stub_msg[] = "no pos";
+
+  if (logging >= 10)
+    {
+    err_msg = (char *)calloc(1, MSG_LEN_LONG);
+    if (msg == NULL)
+      msg = stub_msg;
+    snprintf(err_msg, MSG_LEN_LONG, "locking alljobs_mutex");
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+    }
+
+  if (pthread_mutex_lock(aj->alljobs_mutex) != 0)
+    {
+    if (logging >= 10)
+      {
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot lock alljobs_mutex"); 
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+      }
+    rc = PBSE_MUTEX;
+    }
+
+  if (err_msg != NULL)
+    free(err_msg);
+
+  return rc;
+  }
+
+
+int unlock_alljobs_mutex(
+
+  struct all_jobs *aj,
+  const char      *id,
+  char            *msg,
+  int             logging)
+  {
+  int rc = PBSE_NONE;
+  char *err_msg = NULL;
+  char stub_msg[] = "no pos";
+
+  if (logging >= 10)
+    {
+    err_msg = (char *)calloc(1, MSG_LEN_LONG);
+    if (msg == NULL)
+      msg = stub_msg;
+    snprintf(err_msg, MSG_LEN_LONG, "unlocking alljobs_mutex");
+    log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+    }
+
+  if (pthread_mutex_unlock(aj->alljobs_mutex) != 0)
+    {
+    if (logging >= 10)
+      {
+      snprintf(err_msg, MSG_LEN_LONG, "ALERT: cannot unlock job alljobs_mutex");
+      log_record(PBSEVENT_DEBUG, PBS_EVENTCLASS_NODE, id, err_msg);
+      }
+    rc = PBSE_MUTEX;
+    }
+
+  if (err_msg != NULL)
+    free(err_msg);
+
+  return rc;
+  }
+
+
+  
 #endif  /* NDEBUG */
