@@ -140,8 +140,8 @@ extern struct pbsnode *PGetNodeFromAddr(pbs_net_t);
 
 /* Private Functions local to this file */
 
-static int  local_move(job *, int *, struct batch_request *, int);
-static int should_retry_route(int err);
+int  local_move(job *, int *, struct batch_request *);
+int should_retry_route(int err);
 
 /* Global Data */
 
@@ -186,8 +186,7 @@ int svr_movejob(
   job                  *jobp,
   char                 *destination,
   int                  *my_err,
-  struct batch_request *req,
-  int                   parent_queue_mutex_held)
+  struct batch_request *req)
 
   {
   pbs_net_t     destaddr;
@@ -196,13 +195,19 @@ int svr_movejob(
   char         *toserver;
   char          log_buf[LOCAL_LOG_BUF_SIZE];
 
-  if (strlen(destination) >= (size_t)PBS_MAXROUTEDEST)
+  if (LOGLEVEL >= 7)
+    {
+    sprintf(log_buf, "%s", jobp->ji_qs.ji_jobid);
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
+    }
+
+ if (strlen(destination) >= (size_t)PBS_MAXROUTEDEST)
     {
     sprintf(log_buf, "name %s over maximum length of %d\n",
       destination,
       PBS_MAXROUTEDEST);
 
-    log_err(-1, "svr_movejob", log_buf);
+    log_err(-1, __func__, log_buf);
 
     *my_err = PBSE_QUENBIG;
 
@@ -232,7 +237,7 @@ int svr_movejob(
 
   if (local != 0)
     {
-    return(local_move(jobp, my_err, req, parent_queue_mutex_held));
+    return(local_move(jobp, my_err, req));
     }
 
   return(net_move(jobp, req));
@@ -252,63 +257,30 @@ int svr_movejob(
  *  1 failed but try again
  */
 
-static int local_move(
+int local_move(
 
   job                  *pjob,
   int                  *my_err,
-  struct batch_request *req,
-  int                   parent_queue_mutex_held)
+  struct batch_request *req)
 
   {
-  pbs_queue *routing_que;
-  pbs_queue *dest_que;
-  pbs_queue *tmp_que;
+  pbs_queue *dest_que = NULL;
   char      *destination = pjob->ji_qs.ji_destin;
   int        mtype;
   char       log_buf[LOCAL_LOG_BUF_SIZE];
   char       job_id[PBS_MAXSVRJOBID+1];
   int        rc;
 
-  /* search for destination queue */
-  /* CAUTION!!! This code is very complex - be very careful editing */
-  if (parent_queue_mutex_held == TRUE)
-    routing_que = pjob->ji_qhdr;
-  else
+  /* Sometimes multiple threads are trying to route the same job. Protect against this
+   * by making sure that the destionation queue and the current queue are different. 
+   * If they are the same then consider it done correctly */
+  if (!strcmp(pjob->ji_qs.ji_queue, pjob->ji_qs.ji_destin))
+    return(PBSE_NONE);
+
+  if (LOGLEVEL >= 7)
     {
-    routing_que = get_jobs_queue(&pjob);
-
-    if (pjob == NULL)
-      {
-      log_err(PBSE_JOBNOTFOUND, __func__, "Job lost while acquiring queue 14");
-      return(PBSE_JOBNOTFOUND);
-      }
-    }
-
-  if (routing_que == NULL)
-    {
-    sprintf(log_buf, "queue %s does not exist\n", pjob->ji_qs.ji_queue);
-
-    log_err(-1, __func__, log_buf);
-
-    *my_err = PBSE_UNKQUE;
-
-    return(-1);
-    }
-   
-
-  if (get_parent_dest_queues(pjob->ji_qs.ji_queue, destination, &routing_que, &dest_que, &pjob) != PBSE_NONE)
-    {
-    if (dest_que != NULL)
-      unlock_queue(dest_que, __func__, NULL, 0);
-
-    if ((parent_queue_mutex_held == FALSE) &&
-        (routing_que != NULL))
-      unlock_queue(routing_que, __func__, NULL, 0);
-
-    if (pjob == NULL)
-      return(-10);
-    else
-      return(-1);
+    sprintf(log_buf, "%s", pjob->ji_qs.ji_jobid);
+    log_event(PBSEVENT_JOB, PBS_EVENTCLASS_JOB, __func__, log_buf);
     }
 
   /*
@@ -316,7 +288,6 @@ static int local_move(
    * checks on queue availability, etc. are skipped;
    * otherwise all checks are enforced.
    */
-
   if (req == 0)
     {
     mtype = MOVE_TYPE_Route; /* route */
@@ -330,51 +301,54 @@ static int local_move(
     mtype = MOVE_TYPE_Move; /* non-privileged move */
     }
 
-  /* check the destination */
-  if ((*my_err = svr_chkque(
-                     pjob,
-                     dest_que,
-                     get_variable(pjob, pbs_o_host), mtype, NULL)))
+  strcpy(job_id, pjob->ji_qs.ji_jobid);
+  unlock_ji_mutex(pjob, __func__, NULL, LOGLEVEL);
+
+  dest_que = find_queuebyname(destination);
+
+  if ((pjob = svr_find_job(job_id, TRUE)) == NULL)
     {
-    unlock_queue(dest_que, __func__, NULL, 0);
+    /* job disappeared while locking queue */
+    if (dest_que != NULL)
+      unlock_queue(dest_que, __func__, NULL, LOGLEVEL);
+    
+    return(PBSE_JOB_RECYCLED);
+    }
+
+  if (dest_que == NULL)
+    {
+    /* this should never happen */
+    sprintf(log_buf, "queue %s does not exist\n", pjob->ji_qs.ji_queue);
+    log_err(-1, __func__, log_buf);
+
+    *my_err = PBSE_UNKQUE;
+    return(-1);
+    }
+
+  /* check the destination */
+  if ((*my_err = svr_chkque(pjob, dest_que, get_variable(pjob, pbs_o_host), mtype, NULL)))
+    {
+    unlock_queue(dest_que, __func__, NULL, LOGLEVEL);
 
     /* should this queue be retried? */
-    if (parent_queue_mutex_held == FALSE)
-      unlock_queue(routing_que, __func__, "retry", LOGLEVEL);
-
     return(should_retry_route(*my_err));
     }
 
+  unlock_queue(dest_que, __func__, NULL, LOGLEVEL);
+
   /* dequeue job from present queue, update destination and */
   /* queue_rank for new queue and enqueue into destination  */
-
-  strcpy(job_id, pjob->ji_qs.ji_jobid);
-  unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-  
-  /* if we come out of svr_dequejob successfully pjob->ji_mutex will be locked */
-  rc = svr_dequejob(job_id, TRUE); 
+  rc = svr_dequejob(pjob, FALSE); 
   if (rc)
     return(rc);
 
-  strcpy(pjob->ji_qs.ji_queue, destination);
+  snprintf(pjob->ji_qs.ji_queue, sizeof(pjob->ji_qs.ji_queue), "%s", destination);
 
   pjob->ji_wattr[JOB_ATR_qrank].at_val.at_long = ++queue_rank;
-    
-  unlock_queue(dest_que, __func__, NULL, 0);
-  unlock_queue(routing_que, __func__, "success", LOGLEVEL);
 
   if ((*my_err = svr_enquejob(pjob, FALSE, -1)) == PBSE_JOB_RECYCLED)
     return(-1);
 
-  if (parent_queue_mutex_held == TRUE)
-    {
-    /* re-lock the routing queue */
-    if ((tmp_que = lock_queue_with_job_held(routing_que, &pjob)) == NULL)
-      lock_queue(routing_que, __func__, NULL, 0);
-    else
-      routing_que = tmp_que;
-    }
-
   if (*my_err != PBSE_NONE)
     {
     return(-1); /* should never ever get here */
@@ -582,14 +556,17 @@ void finish_move_process(
     switch (type)
       {
       case MOVE_TYPE_Move:
+
         finish_moving_processing(pjob, preq, status);
         break;
         
       case MOVE_TYPE_Route:
+
         finish_routing_processing(pjob, status);
         break;
         
       case MOVE_TYPE_Exec:
+
         unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
         pjob = NULL;
         finish_sendmom(job_id, preq, time, node_name, status, mom_err);
@@ -597,10 +574,9 @@ void finish_move_process(
         break;
       } /* END switch (type) */
     }
+
   if (pjob != NULL)
     unlock_ji_mutex(pjob, __func__, "2", LOGLEVEL);
-
-
   } /* END finish_move_process() */
 
 
@@ -644,8 +620,7 @@ int send_job_work(
   int                   local_errno = 0;
   tlist_head            attrl;
   enum conn_type        cntype = ToServerDIS;
-  int                   con = -1;
-  int                   sock = -1;
+  int                   con = PBS_NET_RC_UNSET;
   int                   encode_type;
   int                   mom_err = PBSE_NONE;
   int                   i;
@@ -674,7 +649,11 @@ int send_job_work(
   unsigned short        job_momport = -1;
 
   if ((pjob = svr_find_job(job_id, TRUE)) == NULL)
+    {
+    *my_err = PBSE_JOBNOTFOUND;
+    req_reject(-1, 0, preq, NULL, NULL);
     return(PBSE_JOBNOTFOUND);
+    }
 
   if (strlen(pjob->ji_qs.ji_destin) != 0)
     strcpy(job_destin, pjob->ji_qs.ji_destin);
@@ -724,8 +703,7 @@ int send_job_work(
     encode_type = ATR_ENCODE_SVR;
 
     /* clear default resource settings */
-    unlock_ji_mutex(pjob, __func__, "1", LOGLEVEL);
-    ret = svr_dequejob(job_id, FALSE);
+    ret = svr_dequejob(pjob, FALSE);
     if (ret)
       return(ret);
     }
@@ -751,10 +729,18 @@ int send_job_work(
   attrl_fixlink(&attrl);
 
   /* put together the job script file name */
-  if (pjob->ji_arraystruct != NULL)
+  if (pjob->ji_arraystructid[0] != '\0')
     {
-    snprintf(script_name, sizeof(script_name), "%s%s%s",
-      path_jobs, pjob->ji_arraystruct->ai_qs.fileprefix, JOB_SCRIPT_SUFFIX);
+    job_array *pa = get_jobs_array(&pjob);
+
+    if (pa != NULL)
+      {
+      snprintf(script_name, sizeof(script_name), "%s%s%s",
+        path_jobs, pa->ai_qs.fileprefix, JOB_SCRIPT_SUFFIX);
+      unlock_ai_mutex(pa, __func__, NULL, LOGLEVEL);
+      }
+    else if (pjob == NULL)
+      return(PBSE_JOB_RECYCLED);
     }
   else
     {
@@ -795,8 +781,7 @@ int send_job_work(
       if (con >= 0)
         {
         svr_disconnect(con);
-
-        close_conn(sock, FALSE);
+        con = PBS_NET_RC_UNSET;
         }
 
       /* check my_err from previous attempt */
@@ -829,8 +814,13 @@ int send_job_work(
       continue;
       }
 
+    if (con == PBS_LOCAL_CONNECTION)
+      {
+      log_err(-1, __func__, "attempting to run the job on pbs_server???");
+      return(PBSE_SYSTEM);
+      }
+
     pthread_mutex_lock(connection[con].ch_mutex);
-    sock = connection[con].ch_socket;
     pthread_mutex_unlock(connection[con].ch_mutex);
 
     if (attempt_to_queue_job == TRUE)
@@ -993,8 +983,7 @@ int send_job_work(
       }
 
     svr_disconnect(con);
-
-    close_conn(sock, FALSE);
+    con = PBS_NET_RC_UNSET;
 
     /* SUCCESS */
     rc = PBSE_NONE;  /* Equivalent value to LOCUTION_SUCCESS */
@@ -1004,8 +993,6 @@ int send_job_work(
   if (con >= 0)
     {
     svr_disconnect(con);
-
-    close_conn(sock, FALSE);
     }
 
   if (Timeout == TRUE)
@@ -1185,7 +1172,7 @@ int net_move(
  *  -1 if destination should not be retried
  */
 
-static int should_retry_route(
+int should_retry_route(
 
   int err)
 
